      program LINEAR
 
      INCLUDE 'sparse.h'
      external FUN
      DIMENSION  ATOL(NVAR), RTOL(NVAR)
      REAL*8 VOLD(NVAR), VNEW(NVAR)
      integer order
    
      write(6,*) 'Linear. RTOL=, Urban='
      read(5,*) rtols, IS_URBAN

      DT = 3600.
       
C ==== initial values ====
      CFACTOR = 2.55E+10
      CM = 1./CFACTOR
      TEMP = 288.15
      CALL INITVAL()
C --- Adjust initial conditions      
       IF (IS_URBAN.EQ.1) THEN
        do i=1,nvar
           Var(i) = 100.0
        end do   
        Var(I_NO)   = 50*CFACTOR 
        Var(I_NO2)  = 20*CFACTOR
        Var(I_HONO) = 1.0*CFACTOR
        Var(I_O3)   = 100.0*CFACTOR
        Var(I_H2O2) = 1.0*CFACTOR
        Var(I_CO)   = 300.0*CFACTOR
        Var(I_HCHO) = 10.0*CFACTOR
        Var(I_ALD2) = 10.0*CFACTOR
        Var(I_PAN)  = 1.0*CFACTOR
        Var(I_PAR)  = 50.0*CFACTOR 
        Var(I_OLE)  = 10.0*CFACTOR 
        Var(I_ETH)  = 10.0*CFACTOR
        Var(I_TOL)  = 2.0*CFACTOR 
        Var(I_XYL)  = 2.0*CFACTOR 
        Var(I_ISOP) = 10.0*CFACTOR
        Fix(I_H2O)  = 1.35E+7*CFACTOR
       ELSE
        do i=1,nvar
           Var(i) = 100.0
        end do   
        Var(I_NO)   = 0.1*CFACTOR 
        Var(I_NO2)  = 0.1*CFACTOR
        Var(I_O3)   = 30.0*CFACTOR
        Var(I_CO)   = 100.0*CFACTOR
        Var(I_H2O2) = 2.0*CFACTOR
        Var(I_ISOP) = 1.0*CFACTOR
        Fix(I_H2O)  = 1.35E+7*CFACTOR
       END IF
      
      
           
C **********************************************
      open(10, file='Linear.m')


      do i=1,nvar
         atol(i)=1.0
         rtol(i)=rtols
      end do

C ---- TIME VARIABLES ------------------      
      TSTART = 3600*12
      TEND = TSTART + 3600*24*5
      Hmin=1.0d-1
      Hmax=DT




C ********** TIME LOOP *************************
      T = TSTART
      WRITE (10,991) (T-tstart)/3600.D0,(Var(i), i=1,nvar)

      DIV = 3600./DT

      do while(T.lt.TEND)      
        HT=T/3600
        
C --- Add emissions
      IF (IS_URBAN.EQ.1) THEN
        Var(I_NO)   = Var(I_NO)   + 1.0*CFACTOR  /DIV
        Var(I_NO2)  = Var(I_NO2)  + 0.2*CFACTOR  /DIV  
        Var(I_CO)   = Var(I_CO)   + 2.0*CFACTOR  /DIV
        Var(I_HCHO) = Var(I_HCHO) + 0.2*CFACTOR  /DIV
        Var(I_ALD2) = Var(I_ALD2) + 0.2*CFACTOR  /DIV
        Var(I_PAR)  = Var(I_PAR)  + 2.0*CFACTOR  /DIV  
        Var(I_OLE)  = Var(I_OLE)  + 1.0*CFACTOR  /DIV 
        Var(I_ETH)  = Var(I_ETH)  + 0.2*CFACTOR  /DIV 
        Var(I_TOL)  = Var(I_TOL)  + 0.2*CFACTOR  /DIV 
        Var(I_XYL)  = Var(I_XYL)  + 0.2*CFACTOR  /DIV 
        Var(I_ISOP) = Var(I_ISOP) + 1.0*CFACTOR  /DIV
      ELSE
        VAR(I_NO)   = VAR(I_NO)   + 0.01*CFACTOR /DIV
        VAR(I_NO2)  = VAR(I_NO2)  + 0.01*CFACTOR /DIV
        VAR(I_ISOP) = VAR(I_ISOP) + 0.1*CFACTOR   /DIV
      END IF
      
      call RLINEAR2(nvar,t,t+DT,0.1D0,Hmin,Hmax,
     +                   VOLD,Var,VNEW, atol, rtol,
     +                   nfcn,naccpt,nrejec,nstart,startH,FUN)


       
C ---- PRINT VALUES NT TIMES HOURLY ----
      WRITE (10,991) (T-tstart)/3600.D0,(Var(i), i=1,nvar) 
      print *,(T-tstart)/3600.D0,' hrs. O3=', Var(I_O3)/CFACTOR
      end do
C *********** END TIME LOOP ********
      close(10)
      STOP
991   FORMAT(100(X,E24.16))
      END

        SUBROUTINE FUN(N, T, Y, P)
        INCLUDE 'sparse.h'
        REAL*8 Told, T
        REAL*8 Y(NVAR), P(NVAR)

        Told = TIME
        TIME = T
        CALL UPDATE_SUN()
        CALL UPDATE_RCONST()
        CALL F_VAR( Y, RAD, P )
        TIME = Told
        RETURN
        END

        SUBROUTINE JAC_SP(N, T, Y, J)
        INCLUDE 'sparse.h'
        REAL*8 Told, T
        REAL*8 Y(NVAR), J(LU_NONZERO_V)

        Told = TIME
        TIME = T
        CALL UPDATE_SUN()
        CALL UPDATE_RCONST()
        CALL JACVAR_SP( Y, RAD, J )
        TIME = Told
        RETURN
        END
    


      subroutine CLINEAR2(n,t,te,H,Hmin,Hmax,
     +                   yold,y,ynew,atol,rtol,
     +                   nfcn,naccpt,nrejec,nstart,startH,FUN)
      include 'sparse_s.h'

      real*8  F1(nvar), JAC(lu_nonzero_v)
      real*8  atol(nvar), rtol(nvar)      
      DOUBLE COMPLEX S(lu_nonzero_v), K1(nvar)
      external   FUN
      integer	 n,nfcn,naccpt,nrejec,nstart,i,j,order
      real*8	 t,te,H,Hmin,Hmax,startH,ytol,
     +           ratio,Hold,ccc,cp1,errlte
      real*8       yold(nvar),y(nvar),ynew(n)
      logical 	 accept,failer,restart

c
c     Initialization of counters, etc.

      naccpt=0
      nrejec=0
      nfcn=0
      nstart=0
      failer=.false.
      restart=.false.
      accept=.true.

c     Initial stepsize computation. 
    
   10 if (Hmin.eq.Hmax) then
       nstart=1
       H=dmin1(Hmin,(te-t)/2)
       goto 28
      endif
      call FUN(NVAR, T, y, F1)

      nfcn=nfcn+1
      H=te-t
      do 20 i=1,n
       ytol=atol(i)+rtol(i)*dabs(y(i))
       if (F1(i).ne.0.0) H=dmin1(H,ytol/dabs(F1(i)))
   20 continue
   25 nstart=nstart+1
      if (restart) H=H/10.0
      restart=.true.
      H=dmax1( Hmin,dmin1(H,Hmax) )
      call FIT(t,te,H)
      H=dmin1(H,(te-t)/2)
      startH=H

c     The starting step is carried out, using the implicit Euler method.

   28 do 30 i=1,n
       ynew(i)=y(i)
       yold(i)=y(i)
   30 continue

       call JAC_SP(NVAR, T+0.5*H, y, JAC)

       do j=1,lu_nonzero_v
         S(j) = (-0.5*(1,1)*H)*JAC(j)
       end do
       do j=1,NVAR
         S(lu_diag_v(j)) = S(lu_diag_v(j)) + 1.0
       end do

       call CDECOMP (nvar, S, ier)
       if (ier.ne.0) then
         print *,'IER <> 0, H=',H
         stop
       end if  
       
       
       call FUN(NVAR, T+0.5*H, y, F1)
       nfcn=nfcn+1
       
       
       do j = 1,NVAR
         K1(j) = F1(j)
       end do
       call CSOLVE (S, K1)

       do j = 1,NVAR
         y(j) = y(j) + H * DREAL( K1(j) )
       end do

      naccpt=naccpt+1
      t=t+H

c     Subsequent steps are carried out with the two-step BDF method.

      Hold=H
      ratio=1.0
   60 continue
      ccc=1.0/ratio
      cp1=ccc+1.0

       call JAC_SP(NVAR, T+0.5*H, y, JAC)

       do j=1,lu_nonzero_v
         S(j) = (-0.5*(1,1)*H)*JAC(j)
       end do
       do j=1,NVAR
         S(lu_diag_v(j)) = S(lu_diag_v(j)) + 1.0
       end do

       call CDECOMP (nvar, S, ier)
       if (ier.ne.0) then
         print *,'IER <> 0, H=',H
         stop
       end if  
       
       
       call FUN(NVAR, T+0.5*H, y, F1)
       nfcn=nfcn+1
       
       
       do j = 1,NVAR
         K1(j) = F1(j)
       end do
       call CSOLVE (S, K1)

       do j = 1,NVAR
         ynew(j) = y(j) + H * DREAL( K1(j) )
       end do
       

c     If stepsizes should remain equal, stepsize control is omitted.

      if (Hmin.eq.Hmax) then
       t=t+Hold
       naccpt=naccpt+1
       do 85 j=1,n
        yold(j)=y(j)
        y(j)=ynew(j)
   85  continue
       if (H.ne.Hold) then
	t=t-Hold+H
	goto 120
       endif
       H=dmin1(Hold,te-t)
       ratio=H/Hold
       if (t.ge.te) goto 120
       goto 60
      endif

c     Otherwise stepsize control is carried out.

      errlte=0.0
      norm = 2  ! 
      if (norm.eq.1) then
      do 90 i=1,n
       ytol=atol(i)+rtol(i)*dabs(y(i))
       errlte=dmax1(errlte,dabs(ccc*ynew(i)-cp1*y(i)+yold(i))/ytol)
   90 continue
      else if (norm.eq.2) then
      do 91 i=1,n
       ytol=atol(i)+rtol(i)*dabs(y(i))
c       errlte=errlte+( (ccc*ynew(i)-cp1*y(i)+yold(i))/ytol )**2
c       errlte=errlte+( (H*K2(i))/ytol )**2
   91 continue
       errlte = dsqrt(errlte/nvar)
       end if

c      errlte=2.0*errlte/(ccc+ccc*ccc)

C --- Compute the new step size
      if (errlte.gt.1.0.and.H.gt.Hmin) then
       accept=.false.
       ts=t
      else
       accept=.true.
       Hold=H
       ts=t+Hold
      endif
      H=dmax1(1.d-1,dmin1(1.0d+1,0.8/dsqrt(errlte)))*H
      H=dmax1(Hmin,dmin1(H,Hmax))
      call FIT(ts,te,H)
      ratio=H/Hold

c     Here the step has been accepted. 

      if (accept) then
 201   format(2(E24.16,x))
       failer=.false.
       restart=.false.
       t=t+Hold
       naccpt=naccpt+1
       do 100 j=1,n
	yold(j)=y(j)
	y(j)=ynew(j)
  100  continue
       if (t.ge.te) goto 120
       goto 60
      endif

c     A restart check is carried out.
      
      if (failer) then
       nrejec=nrejec+1
       failer=.false.
       naccpt=naccpt-1
       t=t-Hold
       do 110 j=1,n
        y(j)=yold(j)
  110  continue
       goto 25
      endif

c     Here the step has been rejected.

      nrejec=nrejec+1
      failer=.true.
      goto 60
      
c     End of TWOSTEP.
  120 end
c=====================================================================

      subroutine RLINEAR2(n,t,te,H,Hmin,Hmax,
     +                   yold,y,ynew,atol,rtol,
     +                   nfcn,naccpt,nrejec,nstart,startH,FUN)
      include 'sparse_s.h'

      real*8  K1(nvar), K2(nvar)
      real*8  F1(nvar), JAC(lu_nonzero_v)
      real*8  atol(nvar), rtol(nvar) 
      real*8  ghinv
      integer order

      external   FUN
      integer	 n,nfcn,naccpt,nrejec,nstart,i,j
      real*8	 t,te,H,Hmin,Hmax,startH,ytol,
     +           ratio,Hold,ccc,cp1,errlte,m1,m2
      real*8     yold(nvar),y(nvar),ynew(n)
      logical 	 accept,failer,restart

c
c     Initialization of counters, etc.
       gam   = 1.0 - 0.5*dsqrt(2.0d0)
       b2    = 1.0/(2.0*gam)
       b1    = 1.0 - b2
       gam21 = -gam/b2
       c2    = 1.0/(2*b2)
       a21   = 1.0/(2*b2)

      naccpt=0
      nrejec=0
      nfcn=0
      nstart=0
      failer=.false.
      restart=.false.
      accept=.true.
      NJAC = 0

c     Initial stepsize computation. 
    
   10 if (Hmin.eq.Hmax) then
       nstart=1
       H=dmin1(Hmin,(te-t)/2)
       goto 28
      endif
      call FUN(NVAR, T, y, K1)

      nfcn=nfcn+1
      H=te-t
      do 20 i=1,n
       ytol=atol(i)+rtol(i)*dabs(y(i))
       if (K1(i).ne.0.0) H=dmin1(H,ytol/dabs(K1(i)))
   20 continue
   25 nstart=nstart+1
      if (restart) H=H/10.0
      restart=.true.
      H=dmax1( Hmin,dmin1(H,Hmax) )
      call FIT(t,te,H)
      H=dmin1(H,(te-t)/2)
      startH=H

c     The starting step is carried out, using the previously computed function.

   28 do 30 i=1,n
       ynew(i)=y(i)
       yold(i)=y(i)
   30 continue


       gHinv = -1.0d0/(gam*H)
       gH = -gam*H
       call JAC_SP(NVAR, T, y, JAC)
       do j=1,lu_nonzero_v
         JAC(j) = gH*JAC(j) 
       end do
       do j=1,NVAR
         JAC(lu_diag_v(j)) = JAC(lu_diag_v(j)) + 1.0
       end do
       call DECOMP (nvar, JAC, ier)
       if (ier.ne.0) then
         print *,'IER <> 0, H=',H
         stop
       end if         

       call SOLVE (JAC, K1)
      
       xx1 = H*a21
       do j = 1,NVAR
         ynew(j) = y(j) + xx1*K1(j)
       end do

       tau = T + c2*H
       call FUN(NVAR, tau, ynew, F1)
       nfcn=nfcn+1

       xx1 = gam21/gam
       do j = 1,NVAR
         K2(j) = F1(j) + xx1*K1(j) 
       end do
       call SOLVE (JAC, K2)
       
       xx1 = H*(b1-b2*gam21/gam)
       xx2 = H*b2
       do j = 1,NVAR
         ynew(j) = y(j) + xx1*K1(j) + xx2*K2(j) 
         y(j) = ynew(j)
       end do

      naccpt=naccpt+1
      t=t+H

c     Subsequent steps are carried out with the two-step BDF method.

       order = 3
       if (order .eq. 3) then
         gam   = 0.5d0 + dsqrt(3.0d0)/6.0d0
         b2    = 1.0/(3.0*gam**2)
         b1    = 1.0 - b2
         gam21 = 3.0*gam*gam*(0.5-gam) - gam
         c2    = gam
         alpha21   = gam
         c21 = gam21/gam**2
         a21 = alpha21/gam
         m1 = b1/gam-(gam21*b2)/gam**2
         m2 = b2/gam
       else if (order.ne.2) then
         print *, 'Order should be 2 or 3 only.'
         stop  
       end if

      Hold=H
      ratio=1.0
   60 continue
   
      
   
      ccc=1.0/ratio
      cp1=ccc+1.0
      
       
c     Initialization of counters, etc.
       gHinv = -1.0d0/(gam*H)
       call JAC_SP(NVAR, T, y, JAC)
       do j=1,NVAR
         JAC(lu_diag_v(j)) = JAC(lu_diag_v(j)) + gHinv
       end do
       call DECOMP (nvar, JAC, ier)
       if (ier.ne.0) then
         print *,'IER <> 0, H=',H
         stop
       end if  
       

       call FUN(NVAR, T, y, K1)
       nfcn=nfcn+1
       call SOLVE (JAC, K1)
      
       do j = 1,NVAR
         ynew(j) = y(j) - a21*K1(j)
       end do

       tau = T + alpha21*H
       call FUN(NVAR, tau, ynew, F1)
       nfcn=nfcn+1

       xx1 = -C21/H
       do j = 1,NVAR
         K2(j) = F1(j) + xx1*K1(j) 
       end do
       call SOLVE (JAC, K2)
       
       do j = 1,NVAR
         ynew(j) = y(j) - m1*K1(j) - m2*K2(j) 
       end do
       

       

c     If stepsizes should remain equal, stepsize control is omitted.

      if (Hmin.eq.Hmax) then
       t=t+Hold
       naccpt=naccpt+1
       do 85 j=1,n
        yold(j)=y(j)
        y(j)=ynew(j)
   85  continue
       if (H.ne.Hold) then
	t=t-Hold+H
	goto 120
       endif
       H=dmin1(Hold,te-t)
       ratio=H/Hold
       if (t.ge.te) goto 120
       goto 60
      endif

c     Otherwise stepsize control is carried out.

      d1 = b1/gam - gam21/gam**2*(b2-1)
      d2 = (b2-1)/gam
      

      errlte=0.0
      norm = 2  ! 
      if (norm.eq.1) then
      do 90 i=1,n
       ytol=atol(i)+rtol(i)*dabs(y(i))
       errlte=dmax1(errlte,dabs(ccc*ynew(i)-cp1*y(i)+yold(i))/ytol)
   90 continue
      else if (norm.eq.2) then
      do 91 i=1,n
       ytol=atol(i)+rtol(i)*dabs(y(i))
c3m       errlte=errlte+( (ccc*ynew(i)-cp1*y(i)+yold(i))/ytol )**2
       errlte=errlte+( dabs(d1*K1(i)+d2*K2(i))/ytol )**2
   91 continue
       errlte = dsqrt(errlte/nvar)
       end if

c3m      errlte=2.0*errlte/(ccc+ccc*ccc)

C --- Compute the new step size
      if (errlte.gt.1.0.and.H.gt.Hmin) then
       accept=.false.
       ts=t
      else
       accept=.true.
       Hold=H
       ts=t+Hold
      endif
      H=dmax1(1.d-1,dmin1(1.0d+1,0.9/dsqrt(errlte)))*H
      H=dmax1(Hmin,dmin1(H,Hmax))
      call FIT(ts,te,H)
      ratio=H/Hold

c     Here the step has been accepted. 

      if (accept) then
 201   format(2(E24.16,x))
       failer=.false.
       restart=.false.
       t=t+Hold
       naccpt=naccpt+1
       do 100 j=1,n
	yold(j)=y(j)
	y(j)=ynew(j)
  100  continue
       if (t.ge.te) goto 120
       goto 60
      endif

c     A restart check is carried out.
      
      if (failer) then
       nrejec=nrejec+1
       failer=.false.
       naccpt=naccpt-1
       t=t-Hold
       do 110 j=1,n
        y(j)=yold(j)
  110  continue
       goto 25
      endif

c     Here the step has been rejected.

      nrejec=nrejec+1
      failer=.true.
      goto 60
      
c     End of TWOSTEP.
  120 end
c=====================================================================

      subroutine FIT(t,te,H)
      real*8 	t,te,H,rns
      integer 	ns
      rns=(te-t)/H
      if (rns.gt.10.0) goto 10
      ns=int(rns)+1
      H=(te-t)/ns
      H=(H+t)-t
   10 return
      end



C End of MAIN function                                             
C **************************************************************** 


       
