C Original twostep

      program VERWER
 
      INCLUDE 'split.h'
      external ITER
      DIMENSION  V(NVAR), VOLD(NVAR), VNEW(NVAR)
      DIMENSION sum(nvar), p_var(nvar), d_var(nvar), work(nvar)

      write(6,*) 'TwostepS for tropo. rtol=, Niter='
      read(5,*) rtols,numit

      CFACTOR = 1.09E+10
      TEMP = 236.21
      CALL INITVAL()
      do i=1,nvar
         v(i) = var(i)
      end do   
      
           
C **********************************************
      open(10, file='Vseidel.m')

      do i=1,nvar
         atol(i)=1.
         rtol(i)=rtols
      end do

C ---- TIME VARIABLES ------------------      
      TSTART = 3600.*12.
      TEND = TSTART + 3600.*24.*5.
      DT = 3600.
      hmin=1.
      hmax=1200.



        WRITE (10,991) (T-tstart)/3600.D0, (Var(i), i=1,nvar)

C ********** TIME LOOP *************************
      T = TSTART

      do while(T.lt.TEND)      
        HT=T/3600
        
      
      call TWOSTEP(NVAR,t,t+DT,0.1D0,hmin,hmax,
     +                   VOLD,Var,VNEW,p_var,d_var,work,sum,
     +                   atol,rtol,method,numit,
     +                   nfcn,naccpt,nrejec,nstart,startdt)

       
C ---- PRINT VALUES HOURLY ----

C        WRITE (10,991) (T-tstart)/3600.D0, (Var(i), i=1,nvar)

      end do
C *********** END TIME LOOP ********

      close(10)
      STOP
991   FORMAT(100(X,E24.16))
      END


     


      subroutine TWOSTEP(n,t,te,dt,dtmin,dtmax,
     +                   yold,y,ynew,yp,yl,work,sum,
     +                   atol,rtol,method,numit,
     +                   nfcn,naccpt,nrejec,nstart,startdt)
      implicit real*8 (a-h,o-z)
      integer	 n,method,numit,nfcn,naccpt,nrejec,nstart,i,j
      real*8	 t,te,dt,dtmin,dtmax,startdt,ytol,
     +           ratio,dtold,a1,a2,c,cp1,dtg,errlte,dy
      real*8       yold(n),y(n),ynew(n),yp(n),yl(n),
     +           work(n),sum(n),atol(n),rtol(n)
      logical 	 accept,failer,restart

c======================================================================
c
c     AUTHOR: Jan Verwer, Centre for Mathematics and Computer Science 
c     (CWI), Kruislaan 413, 1098 SJ Amsterdam, The Netherlands
c
c     EMAIL ADDRESS: janv@cwi.nl
c
c----------------------------------------------------------------------
c
c     VERSION: November 1994 / 2
c
c----------------------------------------------------------------------
c
c     PURPOSE: TWOSTEP is designed for the numerical solution of
c     stiff ODE systems
c
c	dy(t)/dt = yp(t,y) - yl(y,t)*y(t)
c
c     originating from atmospheric chemistry. Its underlying integration
c     method is the implicit, 2-nd order, 2-step BDF formula. A simple 
c     explicit Gauss-Seidel technique is used for approximating the 
c     implicitly defined BDF solutions, rather than the usual modified 
c     Newton method [1,2]. By this approach TWOSTEP is explicit, whereas
c     the excellent stability of the BDF method is maintained. Also the
c     Jacobi technique may be appropriate. In general, however, its use
c     generally decreases the stability of TWOSTEP and hence also the
c     efficiency.
c
c     While in the prototype solver discussed in [1] the number of 
c     iterations is determined by a convergence criterion, TWOSTEP 
c     works with a fixed, a priori given number of iterations. This
c     leads to a somewhat simpler code and in various experiments
c     this more simple strategy has turned out to be as efficient as 
c     the iteration strategy [2]. In fact, TWOSTEP may work well with
c     only a few iterations per integration step. In this situation
c     TWOSTEP has a workload comparable to explicit solvers based
c     on the quasi-steady-state-approach (QSSA) [3]. Note that when
c     a few Gauss-Seidel iterations are used, the order of the components
c     generally will influence the accuracy. To our experience this
c     influence is minor.
c 
c     [1] J.G. Verwer, Gauss-Seidel iteration for stiff ODEs from
c     chemical kinetics, SIAM Journal on Scientific Computing 15,
c     1243 - 1250, 1994.
c
c     [2] J.G. Verwer & D. Simpson, A comparison between two explicit
c     methods for stiff ODEs from atmospheric chemistry. Report
c     NM-R9414, CWI, Amsterdam, 1994 (to appear in Appl. Numer. Math.).
c
c     [3] J.G. Verwer & M. van Loon,  An evaluation of explicit pseudo-
c     steady-state approximation schemes for stiff ODE systems from
c     chemical kinetics, J. Comput. Phys. 113, 347 - 352, 1994.
c
c----------------------------------------------------------------------
c
c     MEANING OF PARAMETERS:
c
c     n       - Integer. Number of components.
c     t	      - Real. The independent variable time.
c     te      - Real. The endpoint of time.
c     dt      - Real. The stepsize.
c     dtmin   - Real. A minimum for dt.
c     dtmax   - Real. A maximum for dt.
c     yold    - Real array (n). Solution at previous time point.
c     y       - Real array (n). Solution at current time point.
c     ynew    - Real array (n). Solution at forward time point.
c     yp      - Real array (n). Storage for the production term.
c     yl      - Real array (n). Storage for the loss term.
c     work    - Real array (n). Workarray. Only used by ITER.
c     sum     - Real array (n). Workarray for the BDF2 method.
c     atol    - Real array (n). Absolute tolerances.
c     rtol    - Real array (n). Relative tolerances.
c     method  - Integer. Determines whether Gauss-Seidel or Jacobi
c               iteration is used; method only occurs as parameter
c               of subroutine ITER.
c     numit   - Integer. Number of Gauss-Seidel or Jacobi iterations.
c     nfcn    - Integer. The total number of (function) calls of ITER.
c     naccpt  - Integer. The number of accepted integration steps.
c     nrejec  - Integer. The number of rejected integration steps.
c     nstart  - Integer. The number of restarts + 1.
c     startdt - Real. The last computed starting stepsize.
c
c----------------------------------------------------------------------
c
c     STORAGE: 9 real*8 arrays of dimension n.
c
c----------------------------------------------------------------------
c
c     INPUT:      
c
c     n	      - Number of components.
c     t       - Initial time; t is changed.
c     te      - The endpoint of time.
c     dtmin   - The minimal stepsize that TWOSTEP is allowed to use. 
c     dtmax   - The maximal stepsize that TWOSTEP is allowed to use. 
c
c               If on input dtmin = dtmax, then dt:=dtmin and dt is kept
c               fixed throughout the integration, possibly except for
c               the final step where dt may be adjusted to precisely hit
c               the end point te. So, the length of the interval need not be
c               an integer multiple of the selected stepsize.
c
c               If dtmin = dtmax, the stepsize control is switched off.
c               The user thus should ascertain that the integration
c               process remains stable for the selected stepsize. 
c
c               If dtmax > dtmin, then stepsize control is carried out
c               and TWOSTEP determines an initial stepsize itself. However,
c               the control and the initial stepsize selection can be
c               overruled to satisfy the constraint dtmin <= dt <= dtmax.
c
c     y       - Initial solution vector; y is changed.
c     atol    - Absolute tolerances.
c     rtol    - Relative tolerances.
c     method  - method = 0 for the Gauss-Seidel technique.
c               method = 1 for the Jacobi technique.
c
c               The Gauss-Seidel technique is recommended. The user 
c               must program the selected technique in his own
c               subroutine ITER which defines also the ODE system
c               (see below for an example).
c
c     numit   - The number of Gauss-Seidel (or Jacobi iterations) used
c               per time step. This number thus is a priori described
c               for the whole integration. A low number is recommended
c               for Gauss-Seidel iteration [1,2].
c
c               Note that for the Gauss-Seidel technique the order of 
c               the components within ITER will play a role. It is
c               recommended to order the components in decreasing
c               of the loss rates for the very short living species
c               like the radicals. 
c
c----------------------------------------------------------------------
c
c     OUTPUT:      
c
c     t       - t = te.
c     dtold   - The last stepsize value used when working with
c		variable stepsizes.
c     dt      - The last stepsize used to hit the endpoint te
c               when working with constant stepsizes.
c     y       - The computed solution at t = te.
c     nfcn, naccpt, nrejec, nstart, startdt - See MEANING of parameters.
c
c----------------------------------------------------------------------
c
c     SUBROUTINES:
c
c     TWOSTEP calls three subroutines, viz. NEWDT, FIT and ITER. Only
c     subroutine ITER is to be defined by the user.
c
c     NEWDT  - Computes the new stepsize. NEWDT itself calls FIT.
c     FIT    - May adjust dt to guarantee that the remainder
c              of the integration interval is an integer multiple of
c              the current stepsize. The adjustment is carried as soon 
c              as (te-t)/dt <= 10.0. Hence the adjustment may lead to
c              a stepsize smaller than dtmin for approximately
c              ten integration steps.
c     ITER   - A user defined routine for the ODE system. Within ITER
c              also the Gauss-Seidel or Jacobi technique is to be 
c              implemented by the user, as exemplified below:
c
c              subroutine ITER(t,method,n,y,sum,gdt,yp,yl,work)
c              integer    method,n,i,
c              real*8       t,y(n),sum(n),gdt,yp(n),yl(n),work(n)
c
c              if (method.eq.0) then
c              --------------------------------------------------
c              The following statements show how to program the
c              Gauss-Seidel technique. Note that array y is
c              changed. The ispec integers define the order
c              in which the components are processed.       
c              -------------------------------------------------
c              i=ispec1
c              yp(i)= USER DEFINED(t,y)
c              yl(i)= USER DEFINED(t,y)
c              y(i)=(sum(i)+gdt*yp(i))/(1.0+gdt*yl(i))
c
c              i=ispec2
c              yp(i)= USER DEFINED(t,y)
c              yl(i)= USER DEFINED(t,y)
c              y(i)=(sum(i)+gdt*yp(i))/(1.0+gdt*yl(i))
c
c              etcetera
c           
c              else if (method.eq.1) then
c              ------------------------------------------------
c              This shows how to implement the Jacobi technique.
c              Now the order of the components is irrelevant.
c              Note that again y is changed, but only in the
c              second do-loop.
c              ------------------------------------------------
c              for i=1,n
c              yp(i)= USER DEFINED(t,y)
c              yl(i)= USER DEFINED(t,y)
c              enddo
c
c              for i=1,n
c              y(i)=(sum(i)+gdt*yp(i))/(1.0+gdt*yl(i))
c              enddo
c              endif
c              end of ITER
c
c----------------------------------------------------------------------
c
c     EXAMPLE PROGRAM:
c
c     Example program for a 4-species problem based on the three 
c     basic reactions
c
c     	NO2 + hv  ->(k1)  NO + O,  
c       O   + O2  ->(k2)  O3,
c       O3  + NO  ->(k3)  O2 + NO2.
c
c     Here, O = O(3P). Because the first reaction is photochemical
c     k1 depends on the time of the day. Sunrise is at 04.00 hours
c     and sunset at 20.00 hours. NO is emitted. Unit is mol./cm3.
c     Time is in sec. The reaction constants are defined in ITER,
c     like the components yp(i) of the production term and the
c     components yl(i) of the loss term. The integration interval
c     is [14400,417600]. Time=14400 sec. coincides with sunrise at day
c     one and time=417600 sec. coincides with sunset at day five.
c     Below, y(1)=O, y(2)=NO, y(3)=NO2 and y(4)=O3. Output is given
c     in hours at every 2 hours of the last 24 hours. 
c    
c      program    small chemistry
c      integer	  n,numit,nfcn,naccpt,nrejec,nstart,method,
c     +           i,itimeh,i24hrs,inhr
c      real*8  	  time,te,dt,dtmin,dtmax,startdt,timeh,timeod
c      parameter  (n=4)
c      real*8       yold(n),y(n),ynew(n),yp(n),yl(n),atol(n),rtol(n),
c     +  	  work(n),sum(n)
c      external   ITER
c      time=14400.0
c      method=0
c      y(1)=0.0
c      y(2)=1.3e+08
c      y(3)=5.0e+11
c      y(4)=8.0e+11
c      numit=2
c      dtmin=1.0
c      dtmax=900.0
c      do 10 i=1,4
c       atol(i)=1.0
c       rtol(i)=1.0e-3
c   10 continue
c
cc     begin two hourly calculations 
c      do 40 inhr = 1,56
c       te = time + 7200.
c       call TWOSTEP(n,time,te,dt,dtmin,dtmax,
c    +              yold,y,ynew,yp,yl,work,sum,
c     +              atol,rtol,method,numit,
c     +              nfcn,naccpt,nrejec,nstart,startdt)
c       if (inhr.gt.43) then
c        timeh=time/3600
c        itimeh=timeh
c        i24hrs=itimeh/24+1
c        timeod=timeh-(i24hrs-1)*24
c        write(6,30) timeod,y(1),y(2),y(3),y(4)
c   30   format('      Hour = 'f5.2,'   Solution = '4(e9.4,'  '))
c       endif
c   40 continue
c      end
c
c      subroutine ITER(time,method,n,y,sum,gdt,yp,yl,v)
c      integer    method,n
c      real*8	  time,gdt,y(n),sum(n),yp(n),yl(n),v(n)
c      integer    i,itimeh,i24hrs
c      real*8       timeh,timeod,pi,k1,k2,k3,a,b,source,sec
c      logical    night
c
c      timeh=time/3600.0    
c      itimeh=timeh   
c      i24hrs=itimeh/24+1   
c      timeod=timeh-(i24hrs-1)*24.0  
c      pi=4.0*atan(1.0)   
c      sec=(sin((pi/16.0)*(timeod-4.0)))**0.2
c      a=.00001
c      b=-7.0
c      k2=1.0e+05
c      k3=1.0e-16
c      source=1.0e+06
c      night=(timeod.le.4.0.or.timeod.gt.20.0)
c      if (night) then
c       k1=1.0e-40
c      else
c       k1=a*exp(-b*sec)
c      endif
c
c      yp(1)=k1*y(3)
c      yl(1)=k2
c      i=1
c      y(i)=max(0.0,(sum(i)+gdt*yp(i))/(1.0+gdt*yl(i)))
c      yp(2)=k1*y(3)+source
c      yl(2)=k3*y(4)
c      i=2
c      y(i)=max(0.0,(sum(i)+gdt*yp(i))/(1.0+gdt*yl(i)))
c      yp(3)=k3*y(2)*y(4)
c      yl(3)=k1
c      i=3
c      y(i)=max(0.0,(sum(i)+gdt*yp(i))/(1.0+gdt*yl(i)))
c      yp(4)=k2*y(1)
c      yl(4)=k3*y(2)
c      i=4
c      y(i)=max(0.0,(sum(i)+gdt*yp(i))/(1.0+gdt*yl(i)))
c      end
c
c      The output of this example program reads:
c
c      Hour = 20.00   Solution = .1503E+02  .6666E+12  .1503E+12  .1150E+13  
c      Hour = 22.00   Solution = .4837E-33  .3404E+12  .4837E+12  .8162E+12  
c      Hour =  0.00   Solution = .6255E-33  .2058E+12  .6255E+12  .6744E+12  
c      Hour =  2.00   Solution = .7022E-33  .1363E+12  .7022E+12  .5977E+12  
c      Hour =  4.00   Solution = .7495E-33  .9618E+11  .7495E+12  .5504E+12  
c      Hour =  6.00   Solution = .1090E+04  .8191E+12  .3378E+11  .1266E+13  
c      Hour =  8.00   Solution = .1095E+04  .8442E+12  .1596E+11  .1284E+13  
c      Hour = 10.00   Solution = .1106E+04  .8561E+12  .1126E+11  .1289E+13  
c      Hour = 12.00   Solution = .1115E+04  .8644E+12  .1016E+11  .1290E+13  
c      Hour = 14.00   Solution = .1118E+04  .8703E+12  .1138E+11  .1288E+13  
c      Hour = 16.00   Solution = .1109E+04  .8728E+12  .1616E+11  .1284E+13  
c      Hour = 18.00   Solution = .1051E+04  .8636E+12  .3256E+11  .1267E+13  
c      Hour = 20.00   Solution = .1650E+02  .7383E+12  .1650E+12  .1135E+13  
c
c--------------------------------------------------------------------------
c
c     Initialization of counters, etc.

      naccpt=0
      nrejec=0
      nfcn=0
      nstart=0
      failer=.false.
      restart=.false.
      accept=.true.

c     Initial stepsize computation. 
    
   10 if (dtmin.eq.dtmax) then
       nstart=1
       dt=min(dtmin,(te-t)/2)
       goto 28
      endif
      call ITER(t,method,n,y,y,0.0D0,yp,yl,work)
      nfcn=nfcn+1
      dt=te-t
      do 20 i=1,n
       ytol=atol(i)+rtol(i)*abs(y(i))
       dy=yp(i)-y(i)*yl(i)
       if (dy.ne.0.0) dt=min(dt,ytol/abs(dy))
   20 continue
   25 nstart=nstart+1
      if (restart) dt=dt/10.0
      restart=.true.
      dt=max(dtmin,min(dt,dtmax))
      call FIT(t,te,dt)
      dt=min(dt,(te-t)/2)
      startdt=dt

c     The starting step is carried out, using the implicit Euler method.

   28 do 30 i=1,n
       ynew(i)=y(i)
       yold(i)=y(i)
       sum(i)=y(i)
   30 continue
      do 40 i=1,numit
       call ITER(t+dt,method,n,ynew,sum,dt,yp,yl,work)
       nfcn=nfcn+1
   40 continue
      naccpt=naccpt+1
      t=t+dt
      do 50 j=1,n
       y(j)=ynew(j)
   50 continue

c     Subsequent steps are carried out with the two-step BDF method.

      dtold=dt
      ratio=1.0
   60 continue
      c=1.0/ratio
      cp1=c+1.0
      a1=((c+1.0)**2)/(c*c+2.0*c)
      a2=-1.0/(c*c+2.0*c)
      dtg=dt*(1.0+c)/(2.0+c)
      do 70 j=1,n
       sum(j)=a1*y(j)+a2*yold(j)
       ynew(j)=max(0.0,y(j)+ratio*(y(j)-yold(j)))
   70 continue
      do 80 i=1,numit
       call ITER(t+dt,method,n,ynew,sum,dtg,yp,yl,work)
       nfcn=nfcn+1
   80 continue

c     If stepsizes should remain equal, stepsize control is omitted.

      if (dtmin.eq.dtmax) then
       t=t+dtold
       naccpt=naccpt+1
       do 85 j=1,n
        yold(j)=y(j)
        y(j)=ynew(j)
   85  continue
       if (dt.ne.dtold) then
	t=t-dtold+dt
	goto 120
       endif
       dt=min(dtold,te-t)
       ratio=dt/dtold
       if (t.ge.te) goto 120
       goto 60
      endif

c     Otherwise stepsize control is carried out.

      errlte=0.0
      do 90 i=1,n
       ytol=atol(i)+rtol(i)*abs(y(i))
       errlte=max(errlte,abs(c*ynew(i)-cp1*y(i)+yold(i))/ytol)
   90 continue
      errlte=2.0*errlte/(c+c*c)
      call NEWDT(t,te,dt,dtold,ratio,errlte,accept,
     +           dtmin,dtmax)

c     Here the step has been accepted. 

      if (accept) then
       failer=.false.
       restart=.false.
       t=t+dtold
       naccpt=naccpt+1
       do 100 j=1,n
	yold(j)=y(j)
	y(j)=ynew(j)
  100  continue
       if (t.ge.te) goto 120
       goto 60
      endif

c     A restart check is carried out.
      
      if (failer) then
       nrejec=nrejec+1
       failer=.false.
       naccpt=naccpt-1
       t=t-dtold
       do 110 j=1,n
        y(j)=yold(j)
  110  continue
       goto 25
      endif

c     Here the step has been rejected.

      nrejec=nrejec+1
      failer=.true.
      goto 60
      
c     End of TWOSTEP.
  120 end
c=====================================================================

      subroutine NEWDT(t,te,dt,dtold,ratio,errlte,
     +                 accept,dtmin,dtmax)
      implicit real*8 (a-h,o-z)
      real*8    t,te,dt,dtold,ratio,errlte,ts,dtmin,dtmax
      logical accept
      if (errlte.gt.1.0.and.dt.gt.dtmin) then
       accept=.false.
       ts=t
      else
       accept=.true.
       dtold=dt
       ts=t+dtold
      endif
      dt=max(0.5,min(2.0,0.8/sqrt(errlte)))*dt
      dt=max(dtmin,min(dt,dtmax))
      call FIT(ts,te,dt)
      ratio=dt/dtold
      end

      subroutine FIT(t,te,dt)
      implicit real*8 (a-h,o-z)
      real*8 	t,te,dt,rns
      integer 	ns
      rns=(te-t)/dt
      if (rns.gt.10.0) goto 10
      ns=int(rns)+1
      dt=(te-t)/ns
      dt=(dt+t)-t
   10 return
      end


C **************************************************************** 
C                                                                  
C Generated by KPP - symbolic chemistry Kinetics PreProcessor      
C     KPP is developed at CGRER labs University of Iowa by         
C     Valeriu Damian & Adrian Sandu                                
C                                                                  
C File                 : split.f                                   
C Time                 : Thu Sep 14 16:55:04 1995                  
C Working directory    : /local/vol01/users/sandu/AMSTERDAM/SMOG/SPLIT
C Equation file        : split.k                                   
C Output root filename : split                                     
C                                                                  
C **************************************************************** 


      BLOCK DATA GLOBAL_DATA

      INCLUDE 'split.h'

      data CFACTOR / 1 / 

      END


      subroutine ITER(t,method,n,V,sum,gdt,P_VAR,D_VAR,work)
      INCLUDE 'split.h'
      integer method,n
      real*8  t,sum(nvar),gdt,work(nvar)
C V - Concentration of variable species                            
      REAL*8 V(NVAR)
C P_VAR - Production term                                          
      REAL*8 P_VAR(NVAR)
C D_VAR - Destruction term                                         
      REAL*8 D_VAR(NVAR)
C A - rate for each equation                                       
      REAL*8 A(NREACT)

      TOLD = TIME
      TIME = T
      call update_sun()
      call update_rconst()
      TIME = TOLD

C Production function                                              
      A(46) = RCONST(46)*V(65)*V(76)
      A(56) = RCONST(56)*V(39)*V(76)
      A(57) = RCONST(57)*V(65)*V(65)
      A(71) = RCONST(71)*V(48)*V(76)
      A(73) = RCONST(73)*V(49)*V(76)
      A(74) = RCONST(74)*V(38)*V(74)
      A(75) = RCONST(75)*V(60)*V(74)
      A(76) = RCONST(76)*V(76)*V(77)
      A(77) = RCONST(77)*V(77)*V(80)
      A(82) = RCONST(82)*V(48)*V(48)
      A(86) = 0
      A(91) = RCONST(91)*V(52)*V(76)
      A(113) = 0
      A(115) = RCONST(115)*V(53)*V(76)
      A(118) = RCONST(118)*V(59)*V(76)
      A(126) = RCONST(126)*V(50)*V(76)
      A(131) = RCONST(131)*V(57)*V(76)
      A(133) = RCONST(133)*V(64)*V(74)
      A(134) = RCONST(134)*V(74)*V(75)
      A(135) = RCONST(135)*V(73)*V(74)
      A(145) = RCONST(145)*V(46)
      A(149) = RCONST(149)*V(55)*V(76)
      A(153) = RCONST(153)*V(45)*V(76)
      A(157) = RCONST(157)*V(43)*V(76)
      A(173) = RCONST(173)*V(71)
      A(174) = RCONST(174)*V(71)*V(79)
      P_VAR(84) = A(46)+0.8*A(56)+1.4*A(57)+2*A(71)+A(73)+A(74)+0.525
     *           *A(75)+A(76)+A(77)+2.4*A(82)+A(86)+A(91)+A(113)+0.9
     *           *A(115)+0.3*A(118)+0.9*A(126)+A(131)+0.5*A(133)+0.5
     *           *A(134)+0.65*A(135)+A(145)+A(149)+A(153)+A(157)
     *           +A(173)+0.5*A(174)
      D_VAR(84) = RCONST(30)+RCONST(31)+RCONST(32)*V(79)+RCONST(33)
     *           *V(83)+RCONST(38)*V(78)+RCONST(92)*V(77)+RCONST(94)
     *           *V(67)
          V( 84 )=(sum( 84 )+gdt*P_VAR( 84 ))/(1.0+gdt*D_VAR( 84 ))
      A(17) = RCONST(17)*V(41)*V(79)
      A(18) = RCONST(18)*V(74)*V(79)
      A(21) = RCONST(21)*V(31)
      A(25) = RCONST(25)*V(25)*V(79)
      A(27) = RCONST(27)*V(31)
      A(29) = 0
      A(30) = RCONST(30)*V(84)
      A(32) = RCONST(32)*V(79)*V(84)
      A(34) = RCONST(34)*V(37)*V(76)
      A(36) = RCONST(36)*V(37)*V(37)
      A(37) = RCONST(37)*V(33)*V(79)
      A(38) = RCONST(38)*V(78)*V(84)
      A(41) = RCONST(41)*V(82)
      A(46) = RCONST(46)*V(65)*V(76)
      A(49) = RCONST(49)*V(51)*V(76)
      A(51) = RCONST(51)*V(47)*V(76)
      A(53) = RCONST(53)*V(61)*V(76)
      A(57) = RCONST(57)*V(65)*V(65)
      A(58) = RCONST(58)*V(51)*V(51)
      A(59) = RCONST(59)*V(47)*V(47)
      A(71) = RCONST(71)*V(48)*V(76)
      A(73) = RCONST(73)*V(49)*V(76)
      A(74) = RCONST(74)*V(38)*V(74)
      A(75) = RCONST(75)*V(60)*V(74)
      A(82) = RCONST(82)*V(48)*V(48)
      A(83) = RCONST(83)*V(49)*V(49)
      A(96) = RCONST(96)*V(24)*V(79)
      A(97) = RCONST(97)*V(44)*V(76)
      A(99) = RCONST(99)*V(34)*V(79)
      A(100) = RCONST(100)*V(42)
      A(102) = RCONST(102)*V(35)*V(79)
      A(107) = RCONST(107)*V(56)*V(76)
      A(109) = RCONST(109)*V(36)
      A(113) = 0
      A(115) = RCONST(115)*V(53)*V(76)
      A(118) = RCONST(118)*V(59)*V(76)
      A(123) = RCONST(123)*V(66)*V(76)
      A(126) = RCONST(126)*V(50)*V(76)
      A(131) = RCONST(131)*V(57)*V(76)
      A(133) = RCONST(133)*V(64)*V(74)
      A(134) = RCONST(134)*V(74)*V(75)
      A(135) = RCONST(135)*V(73)*V(74)
      A(145) = RCONST(145)*V(46)
      A(146) = RCONST(146)*V(58)
      A(153) = RCONST(153)*V(45)*V(76)
      A(173) = RCONST(173)*V(71)
      P_VAR(83) = A(17)+A(18)+A(21)+A(25)+A(27)+A(29)+2*A(30)+A(32)
     *           +A(34)+2*A(36)+A(37)+A(38)+A(41)+A(46)+A(49)+0.97
     *           *A(51)+0.28*A(53)+0.8*A(57)+1.2*A(58)+0.37*A(59)
     *           +A(71)+A(73)+0.12*A(74)+0.23*A(75)+1.2*A(82)+1.2
     *           *A(83)+0.16*A(96)+A(97)+A(99)+A(100)+0.83*A(102)+0.92
     *           *A(107)+0.98*A(109)+A(113)+0.9*A(115)+0.3*A(118)
     *           +A(123)+0.9*A(126)+A(131)+0.06*A(133)+0.21*A(134)
     *           +0.36*A(135)+2*A(145)+A(146)+0.5*A(153)+A(173)
      D_VAR(83) = RCONST(19)*V(76)+RCONST(20)*V(80)+RCONST(22)*V(74)
     *           +RCONST(23)*2*V(83)+RCONST(33)*V(84)+RCONST(35)*V(37)
     *           +RCONST(60)*V(65)+RCONST(61)*V(51)+RCONST(62)*V(47)
     *           +RCONST(63)*V(61)+RCONST(64)*V(72)+RCONST(69)*V(63)
     *           +RCONST(84)*V(48)+RCONST(85)*V(49)+RCONST(90)*V(52)
     *           +RCONST(110)*V(44)+RCONST(111)*V(56)+RCONST(112)
     *           *V(40)+RCONST(116)*V(53)+RCONST(119)*V(59)
     *           +RCONST(124)*V(66)+RCONST(127)*V(50)+RCONST(132)
     *           *V(57)+RCONST(151)*V(55)+RCONST(154)*V(45)
     *           +RCONST(158)*V(43)+RCONST(160)*V(70)+RCONST(161)
     *           *V(69)+RCONST(172)*V(79)+RCONST(178)*V(78)
          V( 83 )=(sum( 83 )+gdt*P_VAR( 83 ))/(1.0+gdt*D_VAR( 83 ))
      A(49) = RCONST(49)*V(51)*V(76)
      A(51) = RCONST(51)*V(47)*V(76)
      A(53) = RCONST(53)*V(61)*V(76)
      A(56) = RCONST(56)*V(39)*V(76)
      A(58) = RCONST(58)*V(51)*V(51)
      A(59) = RCONST(59)*V(47)*V(47)
      A(66) = RCONST(66)*V(63)*V(76)
      A(73) = RCONST(73)*V(49)*V(76)
      A(75) = RCONST(75)*V(60)*V(74)
      A(79) = RCONST(79)*V(67)*V(76)
      A(80) = RCONST(80)*V(67)*V(80)
      A(82) = RCONST(82)*V(48)*V(48)
      A(83) = RCONST(83)*V(49)*V(49)
      A(87) = 0
      A(91) = RCONST(91)*V(52)*V(76)
      A(134) = RCONST(134)*V(74)*V(75)
      P_VAR(82) = A(49)+0.46*A(51)+1.0482*A(53)+2.1*A(56)+1.6*A(58)
     *           +1.9*A(59)+0.94*A(66)+A(73)+0.5*A(75)+A(79)+A(80)+0.4
     *           *A(82)+2.2*A(83)+A(87)+A(91)+0.15*A(134)
      D_VAR(82) = RCONST(39)*V(79)+RCONST(40)*V(78)+RCONST(41)
     *           +RCONST(42)+RCONST(93)*V(77)+RCONST(95)*V(67)
          V( 82 )=(sum( 82 )+gdt*P_VAR( 82 ))/(1.0+gdt*D_VAR( 82 ))
      A(2) = RCONST(2)*V(74)*V(76)
      A(4) = RCONST(4)*V(76)*V(78)
      A(6) = RCONST(6)*V(26)
      A(7) = RCONST(7)*V(78)*V(80)
      A(8) = RCONST(8)*V(78)
      A(14) = RCONST(14)*V(54)
      A(19) = RCONST(19)*V(76)*V(83)
      A(21) = RCONST(21)*V(31)
      A(26) = RCONST(26)*V(80)*F(2)
      A(27) = RCONST(27)*V(31)
      A(28) = RCONST(28)*V(31)*V(79)
      A(34) = RCONST(34)*V(37)*V(76)
      A(44) = RCONST(44)*V(32)
      A(45) = RCONST(45)*V(72)*V(76)
      A(46) = RCONST(46)*V(65)*V(76)
      A(49) = RCONST(49)*V(51)*V(76)
      A(51) = RCONST(51)*V(47)*V(76)
      A(53) = RCONST(53)*V(61)*V(76)
      A(56) = RCONST(56)*V(39)*V(76)
      A(66) = RCONST(66)*V(63)*V(76)
      A(71) = RCONST(71)*V(48)*V(76)
      A(73) = RCONST(73)*V(49)*V(76)
      A(76) = RCONST(76)*V(76)*V(77)
      A(79) = RCONST(79)*V(67)*V(76)
      A(91) = RCONST(91)*V(52)*V(76)
      A(97) = RCONST(97)*V(44)*V(76)
      A(106) = RCONST(106)*V(21)
      A(107) = RCONST(107)*V(56)*V(76)
      A(108) = RCONST(108)*V(40)*V(76)
      A(115) = RCONST(115)*V(53)*V(76)
      A(118) = RCONST(118)*V(59)*V(76)
      A(122) = RCONST(122)*V(22)
      A(126) = RCONST(126)*V(50)*V(76)
      A(130) = RCONST(130)*V(23)
      A(131) = RCONST(131)*V(57)*V(76)
      A(135) = RCONST(135)*V(73)*V(74)
      A(136) = RCONST(136)*V(69)*V(76)
      A(139) = RCONST(139)*V(70)*V(76)
      A(142) = RCONST(142)*V(68)*V(76)
      A(149) = RCONST(149)*V(55)*V(76)
      A(153) = RCONST(153)*V(45)*V(76)
      A(157) = RCONST(157)*V(43)*V(76)
      A(176) = RCONST(176)*V(78)*V(78)
      A(178) = RCONST(178)*V(78)*V(83)
      P_VAR(80) = A(2)+2*A(4)+A(6)+A(7)+0.85*A(8)+A(14)+A(19)+A(21)
     *           -A(26)+A(27)+A(28)+A(34)+A(44)+A(45)+A(46)+A(49)+0.97
     *           *A(51)+0.9261*A(53)+2.5*A(56)+0.95*A(66)+A(71)+A(73)
     *           +A(76)+A(79)+2*A(91)+A(97)+A(106)+A(107)+A(108)
     *           +A(115)+A(118)+A(122)+A(126)+A(130)+A(131)+0.15
     *           *A(135)+A(136)+A(139)+A(142)+2*A(149)+2*A(153)+2
     *           *A(157)+2*A(176)+0.6*A(178)
      D_VAR(80) = RCONST(1)+RCONST(3)*V(74)+RCONST(5)*V(78)+RCONST(7)
     *           *V(78)+RCONST(13)*V(79)+RCONST(20)*V(83)+RCONST(26)
     *           *F(2)+RCONST(43)*V(72)+RCONST(77)*V(77)+RCONST(80)
     *           *V(67)+RCONST(89)*V(52)+RCONST(105)*V(56)+RCONST(121)
     *           *V(66)+RCONST(129)*V(57)+RCONST(137)*V(69)
     *           +RCONST(140)*V(70)+RCONST(143)*V(68)+RCONST(150)
     *           *V(55)
          V( 80 )=(sum( 80 )+gdt*P_VAR( 80 ))/(1.0+gdt*D_VAR( 80 ))
      A(175) = RCONST(175)*V(20)*V(79)
      P_VAR(81) = 0.5*A(175)
      D_VAR(81) = 0
          V( 81 )=(sum( 81 )+gdt*P_VAR( 81 ))/(1.0+gdt*D_VAR( 81 ))
      A(10) = RCONST(10)*V(74)
      A(12) = RCONST(12)*V(27)
      A(14) = RCONST(14)*V(54)
      A(19) = RCONST(19)*V(76)*V(83)
      A(22) = RCONST(22)*V(74)*V(83)
      A(24) = RCONST(24)*V(25)
      A(102) = RCONST(102)*V(35)*V(79)
      A(173) = RCONST(173)*V(71)
      A(174) = RCONST(174)*V(71)*V(79)
      A(178) = RCONST(178)*V(78)*V(83)
      P_VAR(79) = 2*A(10)+A(12)+A(14)+A(19)+A(22)+2*A(24)-0.9*A(102)
     *           +A(173)+0.5*A(174)+0.6*A(178)
      D_VAR(79) = RCONST(11)*V(76)+RCONST(13)*V(80)+RCONST(15)*V(54)
     *           +RCONST(17)*V(41)+RCONST(18)*V(74)+RCONST(25)*V(25)
     *           +RCONST(28)*V(31)+RCONST(32)*V(84)+RCONST(37)*V(33)
     *           +RCONST(39)*V(82)+RCONST(47)*V(29)+RCONST(48)*V(18)
     *           +RCONST(50)*V(19)+RCONST(52)*V(30)+RCONST(55)*V(28)
     *           +RCONST(65)*V(62)+RCONST(70)*V(38)+RCONST(72)*V(60)
     *           +RCONST(96)*V(24)+RCONST(99)*V(34)+RCONST(101)*V(42)
     *           +RCONST(102)*V(35)+RCONST(104)*V(36)+RCONST(114)
     *           *V(64)+RCONST(117)*V(75)+RCONST(120)*V(73)
     *           +RCONST(125)*V(73)+RCONST(128)*V(46)+RCONST(147)
     *           *V(58)+RCONST(165)*V(16)+RCONST(166)*V(17)
     *           +RCONST(172)*V(83)+RCONST(174)*V(71)+RCONST(175)
     *           *V(20)+RCONST(177)*V(32)
          V( 79 )=(sum( 79 )+gdt*P_VAR( 79 ))/(1.0+gdt*D_VAR( 79 ))
      A(3) = RCONST(3)*V(74)*V(80)
      A(6) = RCONST(6)*V(26)
      A(15) = RCONST(15)*V(54)*V(79)
      A(77) = RCONST(77)*V(77)*V(80)
      A(80) = RCONST(80)*V(67)*V(80)
      A(123) = RCONST(123)*V(66)*V(76)
      A(137) = RCONST(137)*V(69)*V(80)
      A(140) = RCONST(140)*V(70)*V(80)
      A(143) = RCONST(143)*V(68)*V(80)
      P_VAR(78) = A(3)+A(6)+A(15)+A(77)+A(80)+3*A(123)+A(137)+A(140)
     *           +A(143)
      D_VAR(78) = RCONST(4)*V(76)+RCONST(5)*V(80)+RCONST(7)*V(80)
     *           +RCONST(8)+RCONST(38)*V(84)+RCONST(40)*V(82)
     *           +RCONST(54)*V(30)+RCONST(68)*V(62)+RCONST(88)*V(60)
     *           +RCONST(103)*V(35)+RCONST(148)*V(64)+RCONST(152)
     *           *V(75)+RCONST(155)*V(73)+RCONST(156)*V(73)
     *           +RCONST(159)*V(46)+RCONST(176)*2*V(78)+RCONST(178)
     *           *V(83)
          V( 78 )=(sum( 78 )+gdt*P_VAR( 78 ))/(1.0+gdt*D_VAR( 78 ))
      A(74) = RCONST(74)*V(38)*V(74)
      A(75) = RCONST(75)*V(60)*V(74)
      A(133) = RCONST(133)*V(64)*V(74)
      A(134) = RCONST(134)*V(74)*V(75)
      A(135) = RCONST(135)*V(73)*V(74)
      P_VAR(77) = 0.4*A(74)+0.2*A(75)+0.2*A(133)+0.2*A(134)+0.2*A(135)
      D_VAR(77) = RCONST(76)*V(76)+RCONST(77)*V(80)+RCONST(78)*F(2)
     *           +RCONST(92)*V(84)+RCONST(93)*V(82)
          V( 77 )=(sum( 77 )+gdt*P_VAR( 77 ))/(1.0+gdt*D_VAR( 77 ))
      A(1) = RCONST(1)*V(80)
      A(7) = RCONST(7)*V(78)*V(80)
      A(8) = RCONST(8)*V(78)
      A(12) = RCONST(12)*V(27)
      A(53) = RCONST(53)*V(61)*V(76)
      A(56) = RCONST(56)*V(39)*V(76)
      A(123) = RCONST(123)*V(66)*V(76)
      A(135) = RCONST(135)*V(73)*V(74)
      P_VAR(76) = A(1)+A(7)+0.15*A(8)+A(12)-0.1892*A(53)-0.5*A(56)-2
     *           *A(123)-0.15*A(135)
      D_VAR(76) = RCONST(2)*V(74)+RCONST(4)*V(78)+RCONST(11)*V(79)
     *           +RCONST(19)*V(83)+RCONST(34)*V(37)+RCONST(45)*V(72)
     *           +RCONST(46)*V(65)+RCONST(49)*V(51)+RCONST(51)*V(47)
     *           +RCONST(53)*V(61)+RCONST(56)*V(39)+RCONST(66)*V(63)
     *           +RCONST(71)*V(48)+RCONST(73)*V(49)+RCONST(76)*V(77)
     *           +RCONST(79)*V(67)+RCONST(91)*V(52)+RCONST(97)*V(44)
     *           +RCONST(107)*V(56)+RCONST(108)*V(40)+RCONST(115)
     *           *V(53)+RCONST(118)*V(59)+RCONST(123)*V(66)
     *           +RCONST(126)*V(50)+RCONST(131)*V(57)+RCONST(136)
     *           *V(69)+RCONST(139)*V(70)+RCONST(142)*V(68)
     *           +RCONST(149)*V(55)+RCONST(153)*V(45)+RCONST(157)
     *           *V(43)
          V( 76 )=(sum( 76 )+gdt*P_VAR( 76 ))/(1.0+gdt*D_VAR( 76 ))
      A(115) = RCONST(115)*V(53)*V(76)
      A(133) = RCONST(133)*V(64)*V(74)
      A(136) = RCONST(136)*V(69)*V(76)
      A(137) = RCONST(137)*V(69)*V(80)
      A(149) = RCONST(149)*V(55)*V(76)
      A(162) = 0
      A(164) = 0
      P_VAR(75) = 0.45*A(115)+0.2*A(133)+A(136)+A(137)+0.5*A(149)
     *           +A(162)+A(164)
      D_VAR(75) = RCONST(117)*V(79)+RCONST(134)*V(74)+RCONST(152)
     *           *V(78)
          V( 75 )=(sum( 75 )+gdt*P_VAR( 75 ))/(1.0+gdt*D_VAR( 75 ))
      A(1) = RCONST(1)*V(80)
      A(8) = RCONST(8)*V(78)
      P_VAR(74) = A(1)+0.85*A(8)
      D_VAR(74) = RCONST(2)*V(76)+RCONST(3)*V(80)+RCONST(10)
     *           +RCONST(18)*V(79)+RCONST(22)*V(83)+RCONST(74)*V(38)
     *           +RCONST(75)*V(60)+RCONST(133)*V(64)+RCONST(134)*V(75)
     *           +RCONST(135)*V(73)+RCONST(167)*V(11)+RCONST(168)
     *           *V(12)+RCONST(169)*V(13)+RCONST(170)*V(14)
     *           +RCONST(171)*V(15)
          V( 74 )=(sum( 74 )+gdt*P_VAR( 74 ))/(1.0+gdt*D_VAR( 74 ))
      A(115) = RCONST(115)*V(53)*V(76)
      A(133) = RCONST(133)*V(64)*V(74)
      A(139) = RCONST(139)*V(70)*V(76)
      A(140) = RCONST(140)*V(70)*V(80)
      A(149) = RCONST(149)*V(55)*V(76)
      A(163) = 0
      P_VAR(73) = 0.45*A(115)+0.3*A(133)+A(139)+A(140)+0.5*A(149)
     *           +A(163)
      D_VAR(73) = RCONST(120)*V(79)+RCONST(125)*V(79)+RCONST(135)
     *           *V(74)+RCONST(155)*V(78)+RCONST(156)*V(78)
          V( 73 )=(sum( 73 )+gdt*P_VAR( 73 ))/(1.0+gdt*D_VAR( 73 ))
      A(39) = RCONST(39)*V(79)*V(82)
      A(40) = RCONST(40)*V(78)*V(82)
      A(44) = RCONST(44)*V(32)
      A(66) = RCONST(66)*V(63)*V(76)
      A(67) = RCONST(67)*V(62)
      A(100) = RCONST(100)*V(42)
      A(101) = RCONST(101)*V(42)*V(79)
      A(107) = RCONST(107)*V(56)*V(76)
      A(109) = RCONST(109)*V(36)
      A(118) = RCONST(118)*V(59)*V(76)
      A(134) = RCONST(134)*V(74)*V(75)
      A(146) = RCONST(146)*V(58)
      A(147) = RCONST(147)*V(58)*V(79)
      A(153) = RCONST(153)*V(45)*V(76)
      P_VAR(72) = A(39)+A(40)+A(44)+0.94*A(66)+A(67)+A(100)+A(101)
     *           +0.05*A(107)+0.02*A(109)+0.6*A(118)+0.15*A(134)
     *           +A(146)+A(147)+0.5*A(153)
      D_VAR(72) = RCONST(43)*V(80)+RCONST(45)*V(76)+RCONST(64)*V(83)
          V( 72 )=(sum( 72 )+gdt*P_VAR( 72 ))/(1.0+gdt*D_VAR( 72 ))
      A(60) = RCONST(60)*V(65)*V(83)
      A(61) = RCONST(61)*V(51)*V(83)
      A(62) = RCONST(62)*V(47)*V(83)
      A(63) = RCONST(63)*V(61)*V(83)
      A(64) = RCONST(64)*V(72)*V(83)
      A(84) = RCONST(84)*V(48)*V(83)
      A(85) = RCONST(85)*V(49)*V(83)
      A(110) = RCONST(110)*V(44)*V(83)
      A(111) = RCONST(111)*V(56)*V(83)
      A(112) = RCONST(112)*V(40)*V(83)
      A(116) = RCONST(116)*V(53)*V(83)
      A(119) = RCONST(119)*V(59)*V(83)
      A(124) = RCONST(124)*V(66)*V(83)
      A(127) = RCONST(127)*V(50)*V(83)
      A(132) = RCONST(132)*V(57)*V(83)
      A(160) = RCONST(160)*V(70)*V(83)
      A(161) = RCONST(161)*V(69)*V(83)
      P_VAR(71) = A(60)+A(61)+A(62)+A(63)+A(64)+A(84)+A(85)+A(110)
     *           +A(111)+A(112)+A(116)+A(119)+A(124)+A(127)+A(132)
     *           +A(160)+A(161)
      D_VAR(71) = RCONST(173)+RCONST(174)*V(79)
          V( 71 )=(sum( 71 )+gdt*P_VAR( 71 ))/(1.0+gdt*D_VAR( 71 ))
      A(133) = RCONST(133)*V(64)*V(74)
      P_VAR(70) = 0.3*A(133)
      D_VAR(70) = RCONST(139)*V(76)+RCONST(140)*V(80)+RCONST(141)*F(2)
     *           +RCONST(160)*V(83)
          V( 70 )=(sum( 70 )+gdt*P_VAR( 70 ))/(1.0+gdt*D_VAR( 70 ))
      A(133) = RCONST(133)*V(64)*V(74)
      P_VAR(69) = 0.2*A(133)
      D_VAR(69) = RCONST(136)*V(76)+RCONST(137)*V(80)+RCONST(138)*F(2)
     *           +RCONST(161)*V(83)
          V( 69 )=(sum( 69 )+gdt*P_VAR( 69 ))/(1.0+gdt*D_VAR( 69 ))
      A(134) = RCONST(134)*V(74)*V(75)
      A(135) = RCONST(135)*V(73)*V(74)
      P_VAR(68) = 0.2*A(134)+0.2*A(135)
      D_VAR(68) = RCONST(142)*V(76)+RCONST(143)*V(80)+RCONST(144)*F(2)
          V( 68 )=(sum( 68 )+gdt*P_VAR( 68 ))/(1.0+gdt*D_VAR( 68 ))
      A(75) = RCONST(75)*V(60)*V(74)
      P_VAR(67) = 0.2*A(75)
      D_VAR(67) = RCONST(79)*V(76)+RCONST(80)*V(80)+RCONST(81)*F(2)
     *           +RCONST(94)*V(84)+RCONST(95)*V(82)
          V( 67 )=(sum( 67 )+gdt*P_VAR( 67 ))/(1.0+gdt*D_VAR( 67 ))
      A(120) = RCONST(120)*V(73)*V(79)
      A(122) = RCONST(122)*V(22)
      A(155) = RCONST(155)*V(73)*V(78)
      P_VAR(66) = A(120)+A(122)+A(155)
      D_VAR(66) = RCONST(121)*V(80)+RCONST(123)*V(76)+RCONST(124)
     *           *V(83)
          V( 66 )=(sum( 66 )+gdt*P_VAR( 66 ))/(1.0+gdt*D_VAR( 66 ))
      A(41) = RCONST(41)*V(82)
      A(45) = RCONST(45)*V(72)*V(76)
      A(47) = RCONST(47)*V(29)*V(79)
      A(53) = RCONST(53)*V(61)*V(76)
      A(69) = RCONST(69)*V(63)*V(83)
      A(75) = RCONST(75)*V(60)*V(74)
      A(174) = RCONST(174)*V(71)*V(79)
      P_VAR(65) = A(41)+A(45)+A(47)+0.1116*A(53)+A(69)+0.215*A(75)+0.5
     *           *A(174)
      D_VAR(65) = RCONST(46)*V(76)+RCONST(57)*2*V(65)+RCONST(60)*V(83)
          V( 65 )=(sum( 65 )+gdt*P_VAR( 65 ))/(1.0+gdt*D_VAR( 65 ))
      P_VAR(64) = 0
      D_VAR(64) = RCONST(114)*V(79)+RCONST(133)*V(74)+RCONST(148)
     *           *V(78)
          V( 64 )=(sum( 64 )+gdt*P_VAR( 64 ))/(1.0+gdt*D_VAR(64  ))
      A(65) = RCONST(65)*V(62)*V(79)
      A(68) = RCONST(68)*V(62)*V(78)
      P_VAR(63) = A(65)+A(68)
      D_VAR(63) = RCONST(66)*V(76)+RCONST(69)*V(83)
          V( 63 )=(sum( 63 )+gdt*P_VAR( 63 ))/(1.0+gdt*D_VAR( 63 ))
      A(51) = RCONST(51)*V(47)*V(76)
      A(53) = RCONST(53)*V(61)*V(76)
      A(59) = RCONST(59)*V(47)*V(47)  
      P_VAR(62) = 0.49*A(51)+0.3*A(53)+0.28*A(59)
      D_VAR(62) = RCONST(65)*V(79)+RCONST(67)+RCONST(68)*V(78)
          V( 62 )=(sum( 62 )+gdt*P_VAR( 62 ))/(1.0+gdt*D_VAR( 62 ))
      A(52) = RCONST(52)*V(30)*V(79)
      A(53) = RCONST(53)*V(61)*V(76)
      A(54) = RCONST(54)*V(30)*V(78)
      P_VAR(61) = A(52)+0.06*A(53)+A(54)
      D_VAR(61) = RCONST(53)*V(76)+RCONST(63)*V(83)
          V( 61 )=(sum( 61 )+gdt*P_VAR( 61 ))/(1.0+gdt*D_VAR( 61 ))
      P_VAR(60) = 0
      D_VAR(60) = RCONST(72)*V(79)+RCONST(75)*V(74)+RCONST(88)*V(78)
          V( 60 )=(sum( 60 )+gdt*P_VAR( 60 ))/(1.0+gdt*D_VAR( 60 ))
      A(117) = RCONST(117)*V(75)*V(79)
      P_VAR(59) = A(117)
      D_VAR(59) = RCONST(118)*V(76)+RCONST(119)*V(83)
          V( 59 )=(sum( 59 )+gdt*P_VAR( 59 ))/(1.0+gdt*D_VAR( 59 ))


      A(29) = 0
      A(86) = 0
      A(87) = 0
      A(162) = 0
      A(163) = 0
      A(164) = 0
      P_VAR(1) = A(29)+A(86)+A(87)+A(162)+A(163)+A(164)
      D_VAR(1) = 0
          V( 1 )=(sum( 1 )+gdt*P_VAR( 1 ))/(1.0+gdt*D_VAR( 1 ))
      A(81) = RCONST(81)*V(67)*F(2)
      P_VAR(2) = A(81)
      D_VAR(2) = 0
          V( 2 )=(sum( 2 )+gdt*P_VAR( 2 ))/(1.0+gdt*D_VAR( 2 ))
      A(51) = RCONST(51)*V(47)*V(76)
      P_VAR(3) = 0.03*A(51)
      D_VAR(3) = 0
          V( 3 )=(sum( 3 )+gdt*P_VAR( 3 ))/(1.0+gdt*D_VAR( 3 ))
      A(167) = RCONST(167)*V(11)*V(74)
      P_VAR(4) = 0.11*A(167)
      D_VAR(4) = 0
          V( 4 )=(sum( 4 )+gdt*P_VAR( 4 ))/(1.0+gdt*D_VAR( 4 ))
      A(168) = RCONST(168)*V(12)*V(74)
      A(170) = RCONST(170)*V(14)*V(74)
      P_VAR(5) = 0.19*A(168)+0.39*A(170)
      D_VAR(5) = 0
          V( 5 )=(sum( 5 )+gdt*P_VAR( 5 ))/(1.0+gdt*D_VAR( 5 ))
      A(169) = RCONST(169)*V(13)*V(74)
      A(171) = RCONST(171)*V(15)*V(74)
      P_VAR(6) = 0.15*A(169)+0.15*A(171)
      D_VAR(6) = 0
          V( 6 )=(sum( 6 )+gdt*P_VAR( 6 ))/(1.0+gdt*D_VAR( 6 ))
      A(89) = RCONST(89)*V(52)*V(80)
      P_VAR(7) = A(89)
      D_VAR(7) = 0
          V( 7 )=(sum( 7 )+gdt*P_VAR( 7 ))/(1.0+gdt*D_VAR( 7 ))
      A(90) = RCONST(90)*V(52)*V(83)
      P_VAR(8) = A(90)
      D_VAR(8) = 0
          V( 8 )=(sum( 8 )+gdt*P_VAR( 8 ))/(1.0+gdt*D_VAR( 8 ))
      A(92) = RCONST(92)*V(77)*V(84)
      A(93) = RCONST(93)*V(77)*V(82)
      A(94) = RCONST(94)*V(67)*V(84)
      A(95) = RCONST(95)*V(67)*V(82)
      P_VAR(9) = A(92)+A(93)+A(94)+A(95)
      D_VAR(9) = 0
          V( 9 )=(sum( 9 )+gdt*P_VAR( 9 ))/(1.0+gdt*D_VAR( 9 ))
      A(175) = RCONST(175)*V(20)*V(79)
      P_VAR(10) = 0.5*A(175)
      D_VAR(10) = 0
          V( 10 )=(sum( 10 )+gdt*P_VAR( 10 ))/(1.0+gdt*D_VAR( 10 ))
      P_VAR(11) = 0
      D_VAR(11) = RCONST(167)*V(74)
          V( 11 )=(sum( 11 )+gdt*P_VAR( 11 ))/(1.0+gdt*D_VAR( 11 ))
      P_VAR(12) = 0
      D_VAR(12) = RCONST(168)*V(74)
          V( 12 )=(sum( 12 )+gdt*P_VAR( 12 ))/(1.0+gdt*D_VAR( 12 ))
      P_VAR(13) = 0
      D_VAR(13) = RCONST(169)*V(74)
          V( 13 )=(sum( 13 )+gdt*P_VAR( 13 ))/(1.0+gdt*D_VAR( 13 ))
      P_VAR(14) = 0
      D_VAR(14) = RCONST(170)*V(74)
          V( 14 )=(sum( 14 )+gdt*P_VAR( 14 ))/(1.0+gdt*D_VAR( 14 ))
      P_VAR(15) = 0
      D_VAR(15) = RCONST(171)*V(74)
          V( 15 )=(sum( 15 )+gdt*P_VAR( 15 ))/(1.0+gdt*D_VAR( 15 ))
      A(141) = RCONST(141)*V(70)*F(2)
      P_VAR(16) = A(141)
      D_VAR(16) = RCONST(165)*V(79)
          V( 16 )=(sum( 16 )+gdt*P_VAR( 16 ))/(1.0+gdt*D_VAR(16  ))
      A(144) = RCONST(144)*V(68)*F(2)
      P_VAR(17) = A(144)
      D_VAR(17) = RCONST(166)*V(79)
          V( 17 )=(sum( 17 )+gdt*P_VAR( 17 ))/(1.0+gdt*D_VAR( 17 ))
      P_VAR(18) = 0
      D_VAR(18) = RCONST(48)*V(79)
          V( 18 )=(sum( 18 )+gdt*P_VAR( 18 ))/(1.0+gdt*D_VAR( 18 ))
      P_VAR(19) = 0
      D_VAR(19) = RCONST(50)*V(79)
          V(19  )=(sum( 19 )+gdt*P_VAR( 19 ))/(1.0+gdt*D_VAR(19  ))
      P_VAR(20) = 0
      D_VAR(20) = RCONST(175)*V(79)
          V( 20 )=(sum( 20 )+gdt*P_VAR( 20 ))/(1.0+gdt*D_VAR( 20 ))
      A(105) = RCONST(105)*V(56)*V(80)
      P_VAR(21) = A(105)
      D_VAR(21) = RCONST(106)
          V( 21 )=(sum( 21 )+gdt*P_VAR( 21 ))/(1.0+gdt*D_VAR( 21 ))
      A(121) = RCONST(121)*V(66)*V(80)
      P_VAR(22) = A(121)
      D_VAR(22) = RCONST(122)
          V( 22 )=(sum( 22 )+gdt*P_VAR( 22 ))/(1.0+gdt*D_VAR( 22 ))
      A(129) = RCONST(129)*V(57)*V(80)
      P_VAR(23) = A(129)
      D_VAR(23) = RCONST(130)
          V( 23 )=(sum( 23 )+gdt*P_VAR( 23 ))/(1.0+gdt*D_VAR( 23 ))
      P_VAR(24) = 0
      D_VAR(24) = RCONST(96)*V(79)
          V( 24 )=(sum( 24 )+gdt*P_VAR( 24 ))/(1.0+gdt*D_VAR( 24 ))
      A(23) = RCONST(23)*V(83)*V(83)
      P_VAR(25) = A(23)
      D_VAR(25) = RCONST(24)+RCONST(25)*V(79)
          V( 25 )=(sum( 25 )+gdt*P_VAR( 25 ))/(1.0+gdt*D_VAR( 25 ))
      A(5) = RCONST(5)*V(78)*V(80)
      P_VAR(26) = A(5)
      D_VAR(26) = RCONST(6)+RCONST(16)*F(2)
          V( 26 )=(sum( 26 )+gdt*P_VAR( 26 ))/(1.0+gdt*D_VAR( 26 ))
      A(11) = RCONST(11)*V(76)*V(79)
      A(26) = RCONST(26)*V(80)*F(2)
      P_VAR(27) = A(11)+A(26)
      D_VAR(27) = RCONST(12)
          V(27  )=(sum( 27 )+gdt*P_VAR( 27 ))/(1.0+gdt*D_VAR( 27 ))
      A(53) = RCONST(53)*V(61)*V(76)
      A(66) = RCONST(66)*V(63)*V(76)
      P_VAR(28) = 0.2631*A(53)+0.05*A(66)
      D_VAR(28) = RCONST(55)*V(79)
          V( 28 )=(sum( 28 )+gdt*P_VAR( 28 ))/(1.0+gdt*D_VAR( 28 ))
      A(42) = RCONST(42)*V(82)
      A(74) = RCONST(74)*V(38)*V(74)
      P_VAR(29) = A(42)+0.06*A(74)
      D_VAR(29) = RCONST(47)*V(79)
          V( 29 )=(sum( 29 )+gdt*P_VAR( 29 ))/(1.0+gdt*D_VAR( 29 ))
      P_VAR(30) = 0
      D_VAR(30) = RCONST(52)*V(79)+RCONST(54)*V(78)
          V( 30 )=(sum( 30 )+gdt*P_VAR( 30 ))/(1.0+gdt*D_VAR( 30 ))
      A(20) = RCONST(20)*V(80)*V(83)
      P_VAR(31) = A(20)
      D_VAR(31) = RCONST(21)+RCONST(27)+RCONST(28)*V(79)
          V( 31 )=(sum( 31 )+gdt*P_VAR( 31 ))/(1.0+gdt*D_VAR(31  ))
      A(43) = RCONST(43)*V(72)*V(80)
      P_VAR(32) = A(43)
      D_VAR(32) = RCONST(44)+RCONST(177)*V(79)
          V( 32 )=(sum( 32 )+gdt*P_VAR( 32 ))/(1.0+gdt*D_VAR( 32 ))
      A(34) = RCONST(34)*V(37)*V(76)
      A(35) = RCONST(35)*V(37)*V(83)
      A(36) = RCONST(36)*V(37)*V(37)
      A(78) = RCONST(78)*V(77)*F(2)
      P_VAR(33) = A(34)+A(35)+A(36)+A(78)
      D_VAR(33) = RCONST(37)*V(79)
          V( 33 )=(sum( 33 )+gdt*P_VAR( 33 ))/(1.0+gdt*D_VAR(33  ))
      A(97) = RCONST(97)*V(44)*V(76)
      A(107) = RCONST(107)*V(56)*V(76)
      P_VAR(34) = 0.18*A(97)+0.89*A(107)
      D_VAR(34) = RCONST(98)+RCONST(99)*V(79)
          V( 34 )=(sum( 34 )+gdt*P_VAR( 34 ))/(1.0+gdt*D_VAR(34  ))
      A(96) = RCONST(96)*V(24)*V(79)
      P_VAR(35) = 0.16*A(96)
      D_VAR(35) = RCONST(102)*V(79)+RCONST(103)*V(78)
          V( 35 )=(sum( 35 )+gdt*P_VAR(35  ))/(1.0+gdt*D_VAR( 35 ))
      A(97) = RCONST(97)*V(44)*V(76)
      P_VAR(36) = A(97)
      D_VAR(36) = RCONST(104)*V(79)+RCONST(109)
          V( 36 )=(sum( 36 )+gdt*P_VAR( 36 ))/(1.0+gdt*D_VAR( 36 ))
      A(33) = RCONST(33)*V(83)*V(84)
      P_VAR(37) = A(33)
      D_VAR(37) = RCONST(34)*V(76)+RCONST(35)*V(83)+RCONST(36)*2*V(37)
          V( 37 )=(sum( 37 )+gdt*P_VAR( 37 ))/(1.0+gdt*D_VAR( 37 ))
      P_VAR(38) = 0
      D_VAR(38) = RCONST(70)*V(79)+RCONST(74)*V(74)
          V( 38 )=(sum( 38 )+gdt*P_VAR( 38 ))/(1.0+gdt*D_VAR( 38 ))
      A(55) = RCONST(55)*V(28)*V(79)
      P_VAR(39) = A(55)
      D_VAR(39) = RCONST(56)*V(76)
          V( 39 )=(sum( 39 )+gdt*P_VAR( 39 ))/(1.0+gdt*D_VAR( 39 ))
      A(102) = RCONST(102)*V(35)*V(79)
      P_VAR(40) = 0.9*A(102)
      D_VAR(40) = RCONST(108)*V(76)+RCONST(112)*V(83)
          V( 40 )=(sum( 40 )+gdt*P_VAR( 40 ))/(1.0+gdt*D_VAR( 40 ))
      A(30) = RCONST(30)*V(84)
      A(31) = RCONST(31)*V(84)
      A(32) = RCONST(32)*V(79)*V(84)
      A(38) = RCONST(38)*V(78)*V(84)
      A(41) = RCONST(41)*V(82)
      A(42) = RCONST(42)*V(82)
      A(74) = RCONST(74)*V(38)*V(74)
      A(99) = RCONST(99)*V(34)*V(79)
      A(100) = RCONST(100)*V(42)
      A(101) = RCONST(101)*V(42)*V(79)
      P_VAR(41) = A(30)+A(31)+A(32)+A(38)+A(41)+A(42)+0.42*A(74)+2
     *           *A(99)+A(100)+A(101)
      D_VAR(41) = RCONST(17)*V(79)
          V( 41 )=(sum( 41 )+gdt*P_VAR( 41 ))/(1.0+gdt*D_VAR( 41 ))
      A(69) = RCONST(69)*V(63)*V(83)
      A(97) = RCONST(97)*V(44)*V(76)
      A(107) = RCONST(107)*V(56)*V(76)
      P_VAR(42) = A(69)+0.72*A(97)+0.11*A(107)
      D_VAR(42) = RCONST(100)+RCONST(101)*V(79)
          V( 42 )=(sum( 42 )+gdt*P_VAR( 42 ))/(1.0+gdt*D_VAR( 42 ))
      A(156) = RCONST(156)*V(73)*V(78)
      P_VAR(43) = A(156)
      D_VAR(43) = RCONST(157)*V(76)+RCONST(158)*V(83)
          V( 43 )=(sum( 43 )+gdt*P_VAR(43  ))/(1.0+gdt*D_VAR( 43 ))
      A(96) = RCONST(96)*V(24)*V(79)
      P_VAR(44) = 0.84*A(96)
      D_VAR(44) = RCONST(97)*V(76)+RCONST(110)*V(83)
          V( 44 )=(sum( 44 )+gdt*P_VAR( 44 ))/(1.0+gdt*D_VAR( 44 ))
      A(152) = RCONST(152)*V(75)*V(78)
      P_VAR(45) = A(152)
      D_VAR(45) = RCONST(153)*V(76)+RCONST(154)*V(83)
          V( 45 )=(sum( 45 )+gdt*P_VAR( 45 ))/(1.0+gdt*D_VAR( 45 ))
      A(118) = RCONST(118)*V(59)*V(76)
      P_VAR(46) = 0.6*A(118)
      D_VAR(46) = RCONST(128)*V(79)+RCONST(145)+RCONST(159)*V(78)
          V( 46 )=(sum( 46 )+gdt*P_VAR( 46 ))/(1.0+gdt*D_VAR( 46 ))
      A(50) = RCONST(50)*V(19)*V(79)
      A(53) = RCONST(53)*V(61)*V(76)
      P_VAR(47) = A(50)+0.1057*A(53)
      D_VAR(47) = RCONST(51)*V(76)+RCONST(59)*2*V(47)+RCONST(62)*V(83)
          V(47  )=(sum( 47 )+gdt*P_VAR( 47 ))/(1.0+gdt*D_VAR( 47 ))
      A(70) = RCONST(70)*V(38)*V(79)
      P_VAR(48) = A(70)
      D_VAR(48) = RCONST(71)*V(76)+RCONST(82)*2*V(48)+RCONST(84)*V(83)
          V( 48 )=(sum( 48 )+gdt*P_VAR( 48 ))/(1.0+gdt*D_VAR( 48 ))
      A(72) = RCONST(72)*V(60)*V(79)
      P_VAR(49) = A(72)
      D_VAR(49) = RCONST(73)*V(76)+RCONST(83)*2*V(49)+RCONST(85)*V(83)
          V( 49 )=(sum( 49 )+gdt*P_VAR( 49 ))/(1.0+gdt*D_VAR( 49 ))
      A(125) = RCONST(125)*V(73)*V(79)
      P_VAR(50) = A(125)
      D_VAR(50) = RCONST(126)*V(76)+RCONST(127)*V(83)
          V( 50 )=(sum( 50 )+gdt*P_VAR( 50 ))/(1.0+gdt*D_VAR( 50 ))
      A(48) = RCONST(48)*V(18)*V(79)
      A(53) = RCONST(53)*V(61)*V(76)
      A(67) = RCONST(67)*V(62)
      P_VAR(51) = A(48)+0.1879*A(53)+A(67)
      D_VAR(51) = RCONST(49)*V(76)+RCONST(58)*2*V(51)+RCONST(61)*V(83)
          V( 51 )=(sum( 51 )+gdt*P_VAR( 51 ))/(1.0+gdt*D_VAR( 51 ))
      A(88) = RCONST(88)*V(60)*V(78)
      P_VAR(52) = A(88)
      D_VAR(52) = RCONST(89)*V(80)+RCONST(90)*V(83)+RCONST(91)*V(76)
          V( 52 )=(sum( 52 )+gdt*P_VAR( 52 ))/(1.0+gdt*D_VAR( 52 ))
      A(114) = RCONST(114)*V(64)*V(79)
      P_VAR(53) = A(114)
      D_VAR(53) = RCONST(115)*V(76)+RCONST(116)*V(83)
          V( 53 )=(sum( 53 )+gdt*P_VAR( 53 ))/(1.0+gdt*D_VAR( 53 ))
      A(9) = 0
      A(13) = RCONST(13)*V(79)*V(80)
      A(16) = RCONST(16)*V(26)*F(2)
      A(26) = RCONST(26)*V(80)*F(2)
      A(38) = RCONST(38)*V(78)*V(84)
      A(40) = RCONST(40)*V(78)*V(82)
      A(54) = RCONST(54)*V(30)*V(78)
      A(68) = RCONST(68)*V(62)*V(78)
      A(103) = RCONST(103)*V(35)*V(78)
      A(155) = RCONST(155)*V(73)*V(78)
      A(159) = RCONST(159)*V(46)*V(78)
      A(178) = RCONST(178)*V(78)*V(83)
      P_VAR(54) = A(9)+A(13)+2*A(16)+A(26)+A(38)+A(40)+A(54)+A(68)
     *           +A(103)+A(155)+A(159)+0.4*A(178)
      D_VAR(54) = RCONST(14)+RCONST(15)*V(79)
          V( 54 )=(sum( 54 )+gdt*P_VAR( 54 ))/(1.0+gdt*D_VAR( 54 ))
      A(148) = RCONST(148)*V(64)*V(78)
      P_VAR(55) = A(148)
      D_VAR(55) = RCONST(149)*V(76)+RCONST(150)*V(80)+RCONST(151)
     *           *V(83)
          V( 55 )=(sum( 55 )+gdt*P_VAR( 55 ))/(1.0+gdt*D_VAR( 55 ))
      A(102) = RCONST(102)*V(35)*V(79)
      A(104) = RCONST(104)*V(36)*V(79)
      A(106) = RCONST(106)*V(21)
      A(109) = RCONST(109)*V(36)
      P_VAR(56) = 0.9*A(102)+A(104)+A(106)+A(109)
      D_VAR(56) = RCONST(105)*V(80)+RCONST(107)*V(76)+RCONST(111)
     *           *V(83)
          V( 56 )=(sum( 56 )+gdt*P_VAR( 56 ))/(1.0+gdt*D_VAR( 56 ))
      A(128) = RCONST(128)*V(46)*V(79)
      A(130) = RCONST(130)*V(23)
      A(159) = RCONST(159)*V(46)*V(78)
      P_VAR(57) = A(128)+A(130)+A(159)
      D_VAR(57) = RCONST(129)*V(80)+RCONST(131)*V(76)+RCONST(132)
     *           *V(83)
          V( 57 )=(sum( 57 )+gdt*P_VAR( 57 ))/(1.0+gdt*D_VAR( 57 ))
      A(118) = RCONST(118)*V(59)*V(76)
      A(123) = RCONST(123)*V(66)*V(76)
      A(126) = RCONST(126)*V(50)*V(76)
      A(134) = RCONST(134)*V(74)*V(75)
      A(135) = RCONST(135)*V(73)*V(74)
      A(142) = RCONST(142)*V(68)*V(76)
      A(143) = RCONST(143)*V(68)*V(80)
      A(153) = RCONST(153)*V(45)*V(76)
      A(157) = RCONST(157)*V(43)*V(76)
      P_VAR(58) = 0.3*A(118)+A(123)+0.9*A(126)+0.5*A(134)+0.5*A(135)
     *           +A(142)+A(143)+0.5*A(153)+A(157)
      D_VAR(58) = RCONST(146)+RCONST(147)*V(79)
          V( 58 )=(sum( 58 )+gdt*P_VAR( 58 ))/(1.0+gdt*D_VAR( 58 ))
      A(117) = RCONST(117)*V(75)*V(79)

      RETURN
      END

C End of FSPLIT_VAR function                                       
C **************************************************************** 


C **************************************************************** 
C                                                                  
C INITVAL - function to update initial concentrations              
C   Parameters :                                                   
C                                                                  
C **************************************************************** 

      SUBROUTINE INITVAL ( )

      INCLUDE 'split.h'


      INTEGER i
      REAL*8 x

      x = (1.0E-8)*CFACTOR
      do i = 1, NVAR
        VAR(i) = x
      end do

      x = (1.0E-8)*CFACTOR
      do i = 1, NRAD
        RAD(i) = x
      end do

      x = (1.0E-8)*CFACTOR
      do i = 1, NFIX
        FIX(i) = x
      end do

      VAR(1) = (1.0)*CFACTOR
      VAR(25) = (2.0)*CFACTOR
      VAR(29) = (1700)*CFACTOR
      VAR(31) = (1E-8)*CFACTOR
      VAR(41) = (100.0)*CFACTOR
      VAR(74) = (100.0)*CFACTOR
      VAR(76) = (0.05)*CFACTOR
      VAR(78) = (0.1)*CFACTOR
      VAR(80) = (0.05)*CFACTOR
      VAR(81) = (5.0)*CFACTOR
      FIX(1) = (2.E+8)*CFACTOR
      FIX(2) = (500.0)*CFACTOR
      FIX(3) = (5.E+7)*CFACTOR
      FIX(4) = (500)*CFACTOR

      do i = 1, NSPEC
        C_DEFAULT(i) = C(i)
      end do
      RETURN
      END

C End of INITVAL function                                          
C **************************************************************** 


C **************************************************************** 
C                                                                  
C UPDATE_SUN - update SUN light using TIME                         
C   Parameters :                                                   
C                                                                  
C **************************************************************** 

      SUBROUTINE UPDATE_SUN()
      INCLUDE 'split.h'

      REAL*8 SunRise, SunSet
      REAL*8 Thour, Tlocal, Ttmp 
   
      SunRise = 4.5
      SunSet  = 19.5
      Thour = TIME/3600.
      Tlocal = Thour - (int(Thour)/24)*24

      IF ((Tlocal.GE.SunRise).AND.(Tlocal.LE.SunSet)) THEN
        Ttmp = (2.0*Tlocal-SunRise-SunSet)/(SunSet-SunRise)
        IF (Ttmp.GT.0) THEN
          Ttmp =  Ttmp*Ttmp
        ELSE
          Ttmp = -Ttmp*Ttmp
        END IF
        SUN = ( 1.0 + COS(PI*Ttmp) )/2.0 
      ELSE
        SUN=0.0
      END IF

      RETURN
      END

C End of UPDATE_SUN function                                       
C **************************************************************** 


C **************************************************************** 
C                                                                  
C UPDATE_RCONST - function to update rate constants                
C   Parameters :                                                   
C                                                                  
C **************************************************************** 

      SUBROUTINE UPDATE_RCONST ( )

      INCLUDE 'split.h'


      REAL*8 ARR, A, B
      ARR(A,B) = A * EXP(B/TEMP)

      RCONST(1) = (1.074E-2*SUN)
      RCONST(2) = (ARR(2.2*1.0E-12,-1430))
      RCONST(3) = (ARR(1.2*1.0E-13,-2450))
      RCONST(4) = (ARR(1.7*1.0E-11,150))
      RCONST(5) = (1.45*1.0E-12)
      RCONST(6) = (5.00*1.0E-6)
      RCONST(7) = (ARR(2.5*1.0E-14,-1230))
      RCONST(8) = (0.1792*SUN)
      RCONST(10) = (1.353E-7*SUN)
      RCONST(11) = (7.218*1.0E-12)
      RCONST(12) = (2.328E-3*SUN)
      RCONST(13) = (1.2794*1.0E-11)
      RCONST(14) = (8.556E-7*SUN)
      RCONST(15) = (ARR(9.4*1.0E-15,778))
      RCONST(16) = (3.154E-13*SUN)
      RCONST(17) = (1.7823*1.0E-13)
      RCONST(18) = (ARR(1.6*1.0E-12,-1000))
      RCONST(19) = (ARR(3.7*1.0E-12,240))
      RCONST(20) = (1.7851*1.0E-12)
      RCONST(21) = (6.8868*1.0E-6)
      RCONST(22) = (ARR(1.4*1.0E-14,-600))
      RCONST(23) = (4.7165*1.0E-12)
      RCONST(24) = (1.077E-5*SUN)
      RCONST(25) = (1.473E-12*SUN)
      RCONST(26) = (4.00*1.0E-24)
      RCONST(27) = (1.115E-5*SUN)
      RCONST(28) = (ARR(1.3*1.0E-12,380))
      RCONST(30) = (4.251E-5*SUN)
      RCONST(31) = (7.652E-5*SUN)
      RCONST(32) = (1.00*1.0E-11)
      RCONST(33) = (1.00*1.0E-14)
      RCONST(34) = (ARR(4.2*1.0E-12,180))
      RCONST(35) = (2.00*1.0E-12)
      RCONST(36) = (1.00*1.0E-13)
      RCONST(37) = (3.20*1.0E-13)
      RCONST(38) = (6.00*1.0E-16)
      RCONST(39) = (ARR(6.9*1.0E-12,250))
      RCONST(40) = (2.70*1.0E-15)
      RCONST(41) = (2.771E-6*SUN)
      RCONST(42) = (7.562E-5*SUN)
      RCONST(43) = (4.70*1.0E-12)
      RCONST(44) = (ARR(2.2E16,-13435))
      RCONST(45) = (ARR(4.2*1.0E-12,180))
      RCONST(46) = (ARR(4.2*1.0E-12,180))
      RCONST(47) = (1.723E-15*SUN)
      RCONST(48) = (ARR(1.7*1.0E-11,-1232))
      RCONST(49) = (ARR(4.2*1.0E-12,180))
      RCONST(50) = (ARR(1.18*1.0E-11,-679))
      RCONST(51) = (ARR(4.2*1.0E-12,180))
      RCONST(52) = (ARR(2*1.0E-11,-500))
      RCONST(53) = (ARR(4.2*1.0E-12,180))
      RCONST(54) = (4.00*1.0E-17)
      RCONST(55) = (2.00*1.0E-12)
      RCONST(56) = (ARR(4.2*1.0E-12,180))
      RCONST(57) = (ARR(1.5*1.0E-13,220))
      RCONST(58) = (5.00*1.0E-14)
      RCONST(59) = (5.00*1.0E-14)
      RCONST(60) = (3.00*1.0E-12)
      RCONST(61) = (3.00*1.0E-12)
      RCONST(62) = (3.00*1.0E-12)
      RCONST(63) = (3.00*1.0E-12)
      RCONST(64) = (3.00*1.0E-12)
      RCONST(65) = (ARR(1.2*1.0E-11,-890))
      RCONST(66) = (ARR(4.2*1.0E-12,180))
      RCONST(67) = (2.7924E-06*SUN)
      RCONST(68) = (7.00*1.0E-16)
      RCONST(69) = (3.00*1.0E-12)
      RCONST(70) = (ARR(1.66*1.0E-12,474))
      RCONST(71) = (ARR(4.2*1.0E-12,180))
      RCONST(72) = (ARR(4.1*1.0E-12,537))
      RCONST(73) = (ARR(4.2*1.0E-12,180))
      RCONST(74) = (ARR(1.2*1.0E-14,-2633))
      RCONST(75) = (ARR(7.8*1.0E-14,-2105))
      RCONST(76) = (7.00*1.0E-12)
      RCONST(77) = (7.00*1.0E-13)
      RCONST(78) = (4.00*1.0E-18)
      RCONST(79) = (7.00*1.0E-12)
      RCONST(80) = (7.00*1.0E-13)
      RCONST(81) = (4.00*1.0E-18)
      RCONST(82) = (5.00*1.0E-14)
      RCONST(83) = (5.00*1.0E-14)
      RCONST(84) = (3.00*1.0E-12)
      RCONST(85) = (3.00*1.0E-12)
      RCONST(88) = (1.26*1.0E-13)
      RCONST(89) = (6.80*1.0E-12)
      RCONST(90) = (3.00*1.0E-12)
      RCONST(91) = (ARR(4.2*1.0E-12,180))
      RCONST(92) = (1.36*1.0E-14)
      RCONST(93) = (1.36*1.0E-14)
      RCONST(94) = (1.36*1.0E-14)
      RCONST(95) = (1.36*1.0E-14)
      RCONST(96) = (1.52*1.0E-11)
      RCONST(97) = (ARR(4.2*1.0E-12,180))
      RCONST(98) = (8.5920e-05*SUN)
      RCONST(99) = (1.15*1.0E-11)
      RCONST(100) = (2.0406e-04*SUN)
      RCONST(101) = (1.73*1.0E-11)
      RCONST(102) = (4.25*1.0E-11)
      RCONST(103) = (1.00*1.0E-11)
      RCONST(104) = (2.80*1.0E-11)
      RCONST(105) = (4.70*1.0E-12)
      RCONST(106) = (ARR(2.2E16,-13435))
      RCONST(107) = (ARR(4.2*1.0E-12,180))
      RCONST(108) = (ARR(4.2*1.0E-12,180))
      RCONST(109) = (1.074E-4*SUN)
      RCONST(110) = (4.00*1.0E-12)
      RCONST(111) = (4.00*1.0E-12)
      RCONST(112) = (1.00*1.0E-12)
      RCONST(114) = (1.246E-10*SUN)
      RCONST(115) = (ARR(4.2*1.0E-12,180))
      RCONST(116) = (3.00*1.0E-12)
      RCONST(117) = (ARR(3.0*1.0E-12,500))
      RCONST(118) = (ARR(4.2*1.0E-12,180))
      RCONST(119) = (3.0*1.0E-12)
      RCONST(120) = (1.02*1.0E-11)
      RCONST(121) = (4.7*1.0E-12)
      RCONST(122) = (ARR(2.2E+16,-13435))
      RCONST(123) = (ARR(4.2*1.0E-12,180))
      RCONST(124) = (3.00*1.0E-12)
      RCONST(125) = (ARR(3.86*1.0E-12,500))
      RCONST(126) = (ARR(4.2*1.0E-12,180))
      RCONST(127) = (3.00*1.0E-12)
      RCONST(128) = (1.5*1.0E-11)
      RCONST(129) = (4.7*1.0E-12)
      RCONST(130) = (ARR(2.2E+16,-13435))
      RCONST(131) = (ARR(4.2*1.0E-12,180))
      RCONST(132) = (3.00*1.0E-12)
      RCONST(133) = (ARR(7.0*1.0E-15,-1900))
      RCONST(134) = (ARR(4.0*1.0E-15,-2000))
      RCONST(135) = (ARR(4.4*1.0E-15,-2500))
      RCONST(136) = (ARR(4.2*1.0E-12,180))
      RCONST(137) = (ARR(4.2*1.0E-13,180))
      RCONST(138) = (3.4*1.0E-18)
      RCONST(139) = (ARR(4.2*1.0E-12,180))
      RCONST(140) = (ARR(4.2*1.0E-13,180))
      RCONST(141) = (3.4*1.0E-18)
      RCONST(142) = (ARR(4.2*1.0E-12,180))
      RCONST(143) = (ARR(4.2*1.0E-13,180))
      RCONST(144) = (3.4*1.0E-18)
      RCONST(145) = (5.3700e-06*SUN)
      RCONST(146) = (0.0124*SUN)
      RCONST(147) = (1.7*1.0E-11)
      RCONST(148) = (ARR(3.00*1.0E-12,-450))
      RCONST(149) = (ARR(4.2*1.0E-12,180))
      RCONST(150) = (ARR(4.2*1.0E-13,180))
      RCONST(151) = (3.00*1.0E-12)
      RCONST(152) = (6.00*1.0E-14)
      RCONST(153) = (ARR(4.2*1.0E-12,180))
      RCONST(154) = (3.0*1.0E-12)
      RCONST(155) = (3.3*1.0E-15)
      RCONST(156) = (6.7*1.0E-15)
      RCONST(157) = (ARR(4.2*1.0E-12,180))
      RCONST(158) = (3.00*1.0E-12)
      RCONST(159) = (5.2*1.0E-16)
      RCONST(160) = (3.00*1.0E-12)
      RCONST(161) = (3.00*1.0E-12)
      RCONST(165) = (ARR(1.2*1.0E-11,500))
      RCONST(166) = (5.00*1.0E-14)
      RCONST(167) = (5.44*1.0E-17)
      RCONST(168) = (3.46*1.0E-17)
      RCONST(169) = (2.21*1.0E-17)
      RCONST(170) = (1.03*1.0E-15)
      RCONST(171) = (2.16*1.0E-16)
      RCONST(172) = (ARR(4.6*1.0E-11,230))
      RCONST(173) = (5.3700e-06*SUN)
      RCONST(174) = (1.00*1.0E-11)
      RCONST(175) = (8.3*1.0E-12)
      RCONST(176) = (ARR(8.5*1.0E-13,-2450))
      RCONST(177) = (ARR(1.23*1.0E-12,-651))
      RCONST(178) = (ARR(2.3*1.0E-12,170))
      RETURN
      END

C End of UPDATE_RCONST function                                    
C **************************************************************** 




